@@ -1,17 +1,12 @@
 # -*- coding: utf-8 -*-
-
-#  Copyright (c) 2021, University of Luxembourg / DHARPA project
-#  Copyright (c) 2021, Markus Binsteiner
-#
-#  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
-
 import os
-import structlog
 import uuid
+from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Set, Type, Union
+
+import structlog
 
 # from alembic import command  # type: ignore
 from pydantic import Field
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Set, Type, Union
 
 from kiara.context.config import KiaraConfig, KiaraContextConfig, KiaraRuntimeConfig
 from kiara.data_types import DataType
@@ -28,7 +23,7 @@ from kiara.interfaces.python_api.models.info import (
 )
 from kiara.interfaces.python_api.value import StoreValueResult, StoreValuesResult
 from kiara.models import KiaraModel
-from kiara.models.context import ContextSummary
+from kiara.models.context import ContextInfo
 from kiara.models.module.manifest import Manifest
 from kiara.models.runtime_environment import RuntimeEnvironment
 from kiara.models.values.value import ValueMap
@@ -44,12 +39,19 @@ from kiara.registries.jobs import JobRegistry
 from kiara.registries.models import ModelRegistry
 from kiara.registries.modules import ModuleRegistry
 from kiara.registries.operations import OperationRegistry
+from kiara.registries.rendering import RenderRegistry
 from kiara.registries.types import TypeRegistry
 from kiara.registries.workflows import WorkflowRegistry
 from kiara.utils import log_exception
 from kiara.utils.class_loading import find_all_archive_types
 from kiara.utils.operations import filter_operations
 
+#  Copyright (c) 2021, University of Luxembourg / DHARPA project
+#  Copyright (c) 2021, Markus Binsteiner
+#
+#  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
+
+
 if TYPE_CHECKING:
     from kiara.modules import KiaraModule
 
@@ -94,44 +96,19 @@ class Kiara(object):
     how something was created, and in which environment.
     """
 
-    _instances: Dict[str, "Kiara"] = {}
-    _instance_kiara_config = KiaraConfig()
-
     @classmethod
-    def instance(
-        cls,
-        context_name: Union[str, None] = None,
-        runtime_config: Union[None, Mapping[str, Any], KiaraRuntimeConfig] = None,
-    ) -> "Kiara":
+    def instance(cls) -> "Kiara":
         """The default *kiara* context. In most cases, it's recommended you create and manage your own, though."""
 
-        # TODO: make this thread-safe
-        if context_name is None:
-            _context_name = os.environ.get("KIARA_CONTEXT", None)
-        else:
-            _context_name = context_name
+        from kiara.interfaces.python_api import KiaraAPI
 
-        if not _context_name:
-            _context_name = cls._instance_kiara_config.default_context
-
-        if _context_name in cls._instances.keys():
-            instance = cls._instances[_context_name]
-        else:
-            instance = cls._instance_kiara_config.create_context(context=context_name)
-            cls._instances[_context_name] = instance
-
-        if runtime_config:
-            if isinstance(runtime_config, KiaraRuntimeConfig):
-                runtime_config = runtime_config.dict()
-            instance.update_runtime_config(**runtime_config)
-
-        return instance
+        return KiaraAPI.instance().context
 
     def __init__(
         self,
         config: Union[KiaraContextConfig, None] = None,
         runtime_config: Union[KiaraRuntimeConfig, None] = None,
-    ):
+    ) -> None:
 
         kc: Union[KiaraConfig, None] = None
         if not config:
@@ -164,6 +141,8 @@ class Kiara(object):
 
         self._workflow_registry: WorkflowRegistry = WorkflowRegistry(kiara=self)
 
+        self._render_registry = RenderRegistry(kiara=self)
+
         self._env_mgmt: Union[EnvironmentRegistry, None] = None
 
         metadata_augmenter = CreateMetadataDestinies(kiara=self)
@@ -293,6 +272,10 @@ class Kiara(object):
     def event_registry(self) -> EventRegistry:
         return self._event_registry
 
+    @property
+    def render_registry(self) -> RenderRegistry:
+        return self._render_registry
+
     # ===================================================================================================
     # context specific types & instances
 
@@ -350,14 +333,14 @@ class Kiara(object):
 
         return manifest
 
-    def create_module(self, manifest: Union[Manifest, str]) -> "KiaraModule":
-        """Create a [KiaraModule][kiara.module.KiaraModule] object from a module configuration.
-
-        Arguments:
-            manifest: the module configuration
-        """
-
-        return self._module_registry.create_module(manifest=manifest)
+    # def create_module(self, manifest: Union[Manifest, str]) -> "KiaraModule":
+    #     """Create a [KiaraModule][kiara.module.KiaraModule] object from a module configuration.
+    #
+    #     Arguments:
+    #         manifest: the module configuration
+    #     """
+    #
+    #     return self._module_registry.create_module(manifest=manifest)
 
     def queue(
         self, manifest: Manifest, inputs: Mapping[str, Any], wait: bool = False
@@ -423,8 +406,8 @@ class Kiara(object):
 
         return StoreValuesResult.construct(__root__=stored)
 
-    def create_context_summary(self) -> ContextSummary:
-        return ContextSummary.create_from_context(kiara=self)
+    def create_context_summary(self) -> ContextInfo:
+        return ContextInfo.create_from_context(kiara=self)
 
     def get_all_archives(self) -> Dict[KiaraArchive, Set[str]]:
 
@@ -515,7 +498,7 @@ class KiaraContextInfo(KiaraModel):
 
     def get_info(self, item_type: str, item_id: str) -> ItemInfo:
 
-        if "data_type" == item_type or "data_types" == item_type:
+        if item_type == "data_type" or item_type == "data_types":
             group_info: InfoItemGroup = self.data_types
         elif "module" in item_type:
             group_info = self.module_types
