@@ -1,22 +1,22 @@
 # -*- coding: utf-8 -*-
+import contextlib
 
 #  Copyright (c) 2021, University of Luxembourg / DHARPA project
 #  Copyright (c) 2021, Markus Binsteiner
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
-
-
 import os
-import structlog
 import uuid
 from enum import Enum
 from pathlib import Path
+from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Union
+
+import structlog
 from pydantic import BaseModel, root_validator, validator
 from pydantic.config import Extra
 from pydantic.env_settings import BaseSettings
 from pydantic.fields import Field, PrivateAttr
 from ruamel import yaml as r_yaml
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Union
 
 from kiara.defaults import (
     DEFAULT_ALIAS_STORE_MARKER,
@@ -36,7 +36,7 @@ from kiara.utils.files import get_data_from_file
 
 if TYPE_CHECKING:
     from kiara.context import Kiara
-    from kiara.models.context import ContextSummary
+    from kiara.models.context import ContextInfo
 
 logger = structlog.getLogger()
 
@@ -135,6 +135,9 @@ class KiaraRuntimeConfig(BaseSettings):
         description="Name of the strategy that determines when to re-run jobs or use cached results.",
         default=JobCacheStrategy.data_hash,
     )
+    allow_external: bool = Field(
+        description="Whether to allow external external pipelines.", default=True
+    )
     # ignore_errors: bool = Field(
     #     description="If set, kiara will try to ignore most errors (that can be ignored).",
     #     default=False,
@@ -493,12 +496,10 @@ class KiaraConfig(BaseSettings):
     ) -> "Kiara":
 
         if not context:
-            context = DEFAULT_CONTEXT_NAME
+            context = self.default_context
         else:
-            try:
+            with contextlib.suppress(Exception):
                 context = uuid.UUID(context)  # type: ignore
-            except Exception:
-                pass
 
         if isinstance(context, str) and os.path.exists(context):
             context = Path(context)
@@ -564,20 +565,20 @@ class KiaraConfig(BaseSettings):
 
     def delete(
         self, context_name: Union[str, None] = None, dry_run: bool = True
-    ) -> "ContextSummary":
+    ) -> "ContextInfo":
 
         if context_name is None:
             context_name = self.default_context
 
         from kiara.context import Kiara
-        from kiara.models.context import ContextSummary
+        from kiara.models.context import ContextInfo
 
         context_config = self.get_context_config(
             context_name=context_name, auto_generate=False
         )
         kiara = Kiara(config=context_config, runtime_config=self.runtime_config)
 
-        context_summary = ContextSummary.create_from_context(
+        context_summary = ContextInfo.create_from_context(
             kiara=kiara, context_name=context_name
         )
 
