@@ -24,9 +24,11 @@ be discouraged, since this might not be trivial and there are quite a few things
 
 """
 import abc
+import uuid
+from typing import TYPE_CHECKING, Any, Generic, Mapping, Tuple, Type, TypeVar, Union
+
 import orjson
 import structlog
-import uuid
 from deepdiff import DeepHash
 from pydantic import BaseModel, Extra, PrivateAttr, ValidationError
 from rich import box
@@ -34,7 +36,6 @@ from rich.console import Console, ConsoleOptions, RenderResult
 from rich.rule import Rule
 from rich.syntax import Syntax
 from rich.table import Table
-from typing import TYPE_CHECKING, Any, Generic, Mapping, Tuple, Type, TypeVar, Union
 
 from kiara.defaults import (
     INVALID_HASH_MARKER,
@@ -440,7 +441,7 @@ class DataType(abc.ABC, Generic[TYPE_PYTHON_CLS, TYPE_CONFIG_CLS]):
 
             except Exception as e:
                 raise KiaraValueException(
-                    data_type=self.__class__, value_data=data, exception=e
+                    data_type=self.__class__, value_data=data, parent=e
                 )
         else:
             value = Value(
