@@ -6,12 +6,6 @@
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
 import abc
-import orjson
-from pydantic import BaseModel
-from rich import box
-from rich.console import RenderableType
-from rich.syntax import Syntax
-from rich.table import Table
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -24,6 +18,13 @@ from typing import (
     Union,
 )
 
+import orjson
+from pydantic import BaseModel
+from rich import box
+from rich.console import RenderableType
+from rich.syntax import Syntax
+from rich.table import Table
+
 from kiara.data_types import TYPE_CONFIG_CLS, TYPE_PYTHON_CLS, DataType, DataTypeConfig
 from kiara.defaults import INVALID_HASH_MARKER, SpecialValue
 from kiara.exceptions import DataTypeUnknownException, KiaraProcessingException
@@ -162,7 +163,7 @@ class AnyType(
         if not hasattr(self, "_render_as__terminal_renderable"):
 
             try:
-                value.data  # noqa
+                value.data
                 return self.render_as__string(
                     value=value, render_config=render_config, manifest=manifest
                 )
@@ -434,7 +435,7 @@ class DictValueType(AnyType[DictModel, DataTypeConfig]):
                 new_lines = []
                 for line in json_string.split("\n"):
                     if len(line) > width:
-                        new_lines.append(line[0 : width - 3] + "...")  # noqa
+                        new_lines.append(line[0 : width - 3] + "...")
                     else:
                         new_lines.append(line)
 
