@@ -5,25 +5,28 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
-import mmh3
 import os
-import sys
 import typing
 import uuid
-from appdirs import AppDirs
 from enum import Enum
 
+import mmh3
+from appdirs import AppDirs
+
 kiara_app_dirs = AppDirs("kiara", "DHARPA")
 
-if not hasattr(sys, "frozen"):
-    KIARA_MODULE_BASE_FOLDER = os.path.dirname(__file__)
-    """Marker to indicate the base folder for the `kiara` module."""
-else:
-    KIARA_MODULE_BASE_FOLDER = os.path.join(sys._MEIPASS, "kiara")  # type: ignore
-    """Marker to indicate the base folder for the `kiara` module."""
+# if getattr(sys, 'oxidized', False):
+#     KIARA_MODULE_BASE_FOLDER = "xxx"
+#     raise NotImplementedError()
+# elif not hasattr(sys, "_MEIPASS"):
+#     KIARA_MODULE_BASE_FOLDER = os.path.dirname(__file__)
+#     """Marker to indicate the base folder for the `kiara` module."""
+# else:
+#     KIARA_MODULE_BASE_FOLDER = os.path.join(sys._MEIPASS, "kiara")  # type: ignore
+#     """Marker to indicate the base folder for the `kiara` module."""
 
-KIARA_RESOURCES_FOLDER = os.path.join(KIARA_MODULE_BASE_FOLDER, "resources")
-"""Default resources folder for this package."""
+# KIARA_RESOURCES_FOLDER = os.path.join(KIARA_MODULE_BASE_FOLDER, "resources")
+# """Default resources folder for this package."""
 
 KIARA_CONFIG_FILE_NAME = "kiara.config"
 KIARA_DEV_CONFIG_FILE_NAME = "dev.config"
@@ -34,17 +37,7 @@ KIARA_DEV_CONFIG_FILE = os.path.join(
     kiara_app_dirs.user_config_dir, KIARA_DEV_CONFIG_FILE_NAME
 )
 KIARA_MAIN_CONTEXTS_PATH = os.path.join(kiara_app_dirs.user_config_dir, "contexts")
-
-# KIARA_CONTEXTS_FOLDER = os.path.join(kiara_app_dirs.user_data_dir, "contexts")
-# KIARA_STORES_FOLDER = os.path.join(kiara_app_dirs.user_data_dir, "stores")
-
-# KIARA_DB_FILE = os.path.join(kiara_app_dirs.user_data_dir, "kiara.db")
-KIARA_DB_MIGRATIONS_CONFIG = os.path.join(
-    KIARA_RESOURCES_FOLDER, "database", "alembic.ini"
-)
-KIARA_DB_MIGRATIONS_FOLDER = os.path.join(KIARA_RESOURCES_FOLDER, "database", "kiara")
-
-USER_PIPELINES_FOLDER = os.path.join(kiara_app_dirs.user_config_dir, "pipelines")
+# USER_PIPELINES_FOLDER = os.path.join(kiara_app_dirs.user_config_dir, "pipelines")
 
 
 MODULE_TYPE_KEY = "module_type"
@@ -112,6 +105,7 @@ DEFAULT_PIPELINE_PARENT_ID = "__kiara__"
 """Default parent id for pipeline objects that are not associated with a workflow."""
 
 DEFAULT_NO_DESC_VALUE = "-- n/a --"
+NOT_AVAILBLE_MARKER = "-- n/a --"
 
 KIARA_MODULE_METADATA_ATTRIBUTE = "KIARA_METADATA"
 
@@ -257,3 +251,12 @@ For more information, please visit:
 - https://dharpa.org/kiara.documentation/latest/installation/#enable-developer-mode
 - https://learn.microsoft.com/en-us/windows/apps/get-started/enable-your-device-for-development
 """
+
+
+OFFICIAL_KIARA_PLUGINS = [
+    "core_types",
+    "tabular",
+    "onboarding",
+    "network_analysis",
+    "language_processing",
+]
