@@ -4,14 +4,14 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
-import os
 import typing
+
 from mkdocstrings.handlers.base import BaseHandler
 
-__all__ = ["get_handler"]  # noqa: WPS410
+__all__ = ["get_handler"]
 
 
-from kiara.defaults import KIARA_RESOURCES_FOLDER
+# from kiara.defaults import KIARA_RESOURCES_FOLDER
 from kiara.doc.mkdocstrings.collector import KiaraCollector
 from kiara.doc.mkdocstrings.renderer import KiaraInfoRenderer
 
@@ -55,12 +55,12 @@ class KiaraHandler(BaseHandler):
     #
     #     for item in Inventory.parse_sphinx(
     #         in_file, domain_filter=("py",)
-    #     ).values():  # noqa: WPS526
+    #     ).values():
     #         yield item.name, posixpath.join(base_url, item.uri)
 
 
 def get_handler(
-    theme: str,  # noqa: W0613 (unused argument config)
+    theme: str,
     custom_templates: typing.Union[str, None] = None,
     **config: typing.Any,
 ) -> KiaraHandler:
@@ -76,11 +76,12 @@ def get_handler(
     if custom_templates is not None:
         raise Exception("Custom templates are not supported for the kiara renderer.")
 
-    custom_templates = os.path.join(
-        KIARA_RESOURCES_FOLDER, "templates", "info_templates"
-    )
+    # custom_templates = os.path.join(
+    #     KIARA_RESOURCES_FOLDER, "templates", "info_templates"
+    # )
 
     return KiaraHandler(
         collector=KiaraCollector(),
-        renderer=KiaraInfoRenderer("kiara", theme, custom_templates),
+        # renderer=KiaraInfoRenderer("kiara", theme, custom_templates),
+        renderer=KiaraInfoRenderer("kiara", theme),
     )
