@@ -5,6 +5,7 @@
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
 import typing
+
 from mkdocstrings.handlers.base import BaseRenderer, CollectorItem
 
 
@@ -16,14 +17,12 @@ class KiaraInfoRenderer(BaseRenderer):
 
     default_config: dict = {}
 
-    def get_anchors(
-        self, data: CollectorItem
-    ) -> typing.List[str]:  # noqa: D102 (ignore missing docstring)
+    def get_anchors(self, data: CollectorItem) -> typing.List[str]:
 
         if data is None:
-            return list()
+            return []
 
-        return list([data["identifier"], data["kiara_id"], data["obj"].get_id()])
+        return [data["identifier"], data["kiara_id"], data["obj"].get_id()]
 
     def render(self, data: typing.Dict[str, typing.Any], config: dict) -> str:
 
