@@ -7,21 +7,88 @@
 import uuid
 from typing import TYPE_CHECKING, Any, Iterable, List, Mapping, Type, Union
 
+from orjson import orjson
+from rich.markdown import Markdown
+
+from kiara.defaults import NOT_AVAILBLE_MARKER
+from kiara.utils.json import orjson_dumps
+
 if TYPE_CHECKING:
+    from rich.console import RenderableType
     from rich.table import Table
 
     from kiara.data_types import DataType
     from kiara.models.module.jobs import ActiveJob
     from kiara.models.module.manifest import Manifest
+    from kiara.models.module.pipeline import PipelineConfig
     from kiara.models.values.value import Value
     from kiara.modules import KiaraModule
 
 
 class KiaraException(Exception):
-    pass
+    @classmethod
+    def get_root_details(cls, e: Exception) -> Union[str, None]:
+
+        if isinstance(e, KiaraException):
+            return e.root_details()
+        else:
+            return str(e)
+
+    def __init__(self, msg: str, parent: Union[Exception, None] = None, **kwargs):
+
+        self._parent: Union[Exception, None] = parent
+        self._properties = kwargs
+        super().__init__(msg)
+
+    @property
+    def details(self) -> Union[str, None]:
+
+        return self._properties.get("details", None)
+
+    @property
+    def parent(self) -> Union[Exception, None]:
+        return self._parent
+
+    @property
+    def root_cause(self) -> Exception:
+
+        current: Exception = self
+        while hasattr(current, "parent") and current.parent is not None:  # type: ignore
+            current = current.parent  # type: ignore
+
+        return current
+
+    def root_details(self) -> Union[str, None]:
+
+        current: Exception = self
+        if hasattr(self, "details"):
+            current_details = self.details  # type: ignore
+        else:
+            current_details = None
+        while hasattr(current, "parent") and current.parent is not None:  # type: ignore
+            current = current.parent  # type: ignore
+
+            if hasattr(current, "details") and current.details:  # type: ignore
+                current_details = current.details  # type: ignore
+            else:
+                current_details = str(current)
+
+        return current_details
+
+    def create_renderable(self, **config) -> "RenderableType":
+
+        from rich.console import Group
+
+        rows: List[RenderableType] = [f"[red]Error[/red]: {str(self)}"]
+        root_details = self.root_details()
+        if root_details:
+            rows.append("")
+            rows.append(Markdown(root_details))
+
+        return Group(*rows)
 
 
-class KiaraModuleConfigException(Exception):
+class KiaraModuleConfigException(KiaraException):
     def __init__(
         self,
         msg: str,
@@ -33,17 +100,43 @@ class KiaraModuleConfigException(Exception):
         self._module_cls = module_cls
         self._config = config
 
-        self._parent: Union[Exception, None] = parent
-
         if not msg.endswith("."):
             _msg = msg + "."
         else:
             _msg = msg
 
-        super().__init__(_msg)
+        super().__init__(_msg, parent=parent)
 
 
-class ValueTypeConfigException(Exception):
+class InvalidManifestException(KiaraException):
+    def __init__(
+        self,
+        msg: str,
+        module_type: str,
+        module_config: Union[None, Mapping[str, Any]] = None,
+        available_module_types: Union[None, Iterable[str]] = None,
+        parent: Union[Exception, None] = None,
+    ):
+
+        self._module_type = module_type
+        self._module_config = module_config
+        self._available_module_types = available_module_types
+        super().__init__(msg, parent=parent)
+
+    @property
+    def details(self) -> Union[str, None]:
+
+        if not self._available_module_types:
+            return None
+
+        else:
+            msg = "Available module types:\n\n"
+            for module_type in self._available_module_types:
+                msg += f"- {module_type}\n"
+            return msg
+
+
+class ValueTypeConfigException(KiaraException):
     def __init__(
         self,
         msg: str,
@@ -55,17 +148,15 @@ class ValueTypeConfigException(Exception):
         self._type_cls = type_cls
         self._config = config
 
-        self._parent: Union[Exception, None] = parent
-
         if not msg.endswith("."):
             _msg = msg + "."
         else:
             _msg = msg
 
-        super().__init__(_msg)
+        super().__init__(_msg, parent=parent)
 
 
-class DataTypeUnknownException(Exception):
+class DataTypeUnknownException(KiaraException):
     def __init__(
         self,
         data_type: str,
@@ -111,25 +202,24 @@ class DataTypeUnknownException(Exception):
         return table
 
 
-class KiaraValueException(Exception):
+class KiaraValueException(KiaraException):
     def __init__(
         self,
         data_type: Type["DataType"],
         value_data: Any,
-        exception: Exception,
+        parent: Exception,
     ):
         self._data_type: Type["DataType"] = data_type
         self._value_data: Any = value_data
-        self._exception: Exception = exception
 
-        exc_msg = str(self._exception)
+        exc_msg = str(parent)
         if not exc_msg:
             exc_msg = "no details available"
 
-        super().__init__(f"Invalid value of type '{data_type._data_type_name}': {exc_msg}")  # type: ignore
+        super().__init__(f"Invalid value of type '{data_type._data_type_name}': {exc_msg}", parent=parent)  # type: ignore
 
 
-class NoSuchExecutionTargetException(Exception):
+class NoSuchExecutionTargetException(KiaraException):
     def __init__(
         self,
         selected_target: str,
@@ -144,7 +234,7 @@ class NoSuchExecutionTargetException(Exception):
         super().__init__(msg)
 
 
-class KiaraProcessingException(Exception):
+class KiaraProcessingException(KiaraException):
     def __init__(
         self,
         msg: Union[str, Exception],
@@ -174,7 +264,7 @@ class KiaraProcessingException(Exception):
         return self._parent
 
 
-class InvalidValuesException(Exception):
+class InvalidValuesException(KiaraException):
     def __init__(
         self,
         msg: Union[None, str, Exception] = None,
@@ -203,6 +293,14 @@ class InvalidValuesException(Exception):
 
         super().__init__(_msg)
 
+    @property
+    def details(self) -> str:
+        result = ""
+        for k, v in self.invalid_inputs.items():
+            result += f" - {k}: {v}"
+
+        return result
+
     def create_renderable(self, **config: Any) -> "Table":
 
         from rich import box
@@ -223,7 +321,7 @@ class InvalidValuesException(Exception):
         return table
 
 
-class JobConfigException(Exception):
+class JobConfigException(KiaraException):
     def __init__(
         self,
         msg: Union[str, Exception],
@@ -252,14 +350,23 @@ class JobConfigException(Exception):
         return self._inputs
 
 
-class FailedJobException(Exception):
-    def __init__(self, job: "ActiveJob", msg: Union[str, None] = None):
+class FailedJobException(KiaraException):
+    def __init__(
+        self,
+        job: "ActiveJob",
+        msg: Union[str, None] = None,
+        parent: Union[Exception, None] = None,
+    ):
 
         self.job: ActiveJob = job
         if msg is None:
             msg = "Job failed."
         self.msg = msg
-        super().__init__(msg)
+        super().__init__(msg, parent=parent)
+
+    @property
+    def details(self) -> Union[str, None]:
+        return None
 
     def create_renderable(self, **config: Any):
 
@@ -281,7 +388,7 @@ class FailedJobException(Exception):
         return group
 
 
-class NoSuchValueException(Exception):
+class NoSuchValueException(KiaraException):
 
     pass
 
@@ -302,7 +409,7 @@ class NoSuchValueAliasException(NoSuchValueException):
         super().__init__(msg)
 
 
-class NoSuchWorkflowException(Exception):
+class NoSuchWorkflowException(KiaraException):
     def __init__(self, workflow: Union[uuid.UUID, str], msg: Union[str, None] = None):
         self._workflow: Union[str, uuid.UUID] = workflow
         if not msg:
@@ -322,7 +429,7 @@ class NoSuchWorkflowException(Exception):
             return False
 
 
-class NoSuchOperationException(Exception):
+class NoSuchOperationException(KiaraException):
     def __init__(
         self,
         operation_id: str,
@@ -334,7 +441,7 @@ class NoSuchOperationException(Exception):
         self._available_operations: Iterable[str] = available_operations
 
         if not msg:
-            msg = f"No operation with id: {operation_id} available."
+            msg = f"No operation with id '{operation_id}' available."
 
         super().__init__(msg)
 
@@ -345,3 +452,63 @@ class NoSuchOperationException(Exception):
     @property
     def operation_id(self) -> str:
         return self._operation_id
+
+
+class InvalidOperationException(KiaraException):
+    def __init__(self, operation_details: Mapping[str, Any]):
+
+        self._all_details: Mapping[str, Any] = operation_details
+        msg = operation_details.get("operation_id", None)
+        if msg is None:
+            msg = operation_details.get("pipeline_name", None)
+        parent = operation_details.get("parent", None)
+        super().__init__(f"Invalid operation: {msg}", parent=parent)
+
+    @property
+    def module_id(self) -> str:
+        return self._all_details.get("module_id", NOT_AVAILBLE_MARKER)
+
+    @property
+    def module_config(self) -> Union[Mapping[str, Any], str]:
+        return self._all_details.get("module_config", {})
+
+    @property
+    def details(self) -> Union[str, None]:
+        if self.parent:
+            if hasattr(self.parent, "details"):
+                return self.parent.details  # type: ignore
+            else:
+                return None
+        else:
+            return self._all_details.get("details", None)
+
+
+class InvalidPipelineStepConfig(KiaraException):
+    def __init__(self, msg: str, step_config: Mapping[str, Any]):
+
+        self._step_config: Mapping[str, Any] = step_config
+        super().__init__(msg)
+
+    @property
+    def details(self) -> str:
+        config = orjson_dumps(self._step_config, option=orjson.OPT_INDENT_2)
+
+        details = f"Invalid step config:\n\n```\n{config}\n```"
+        return details
+
+
+class InvalidPipelineConfig(KiaraException):
+    def __init__(self, msg: str, config: "PipelineConfig", details: str):
+
+        self._config = config
+        self._details = details
+        super().__init__(msg)
+
+    @property
+    def pipeline_config(self) -> "PipelineConfig":
+        return self._config
+
+    @property
+    def details(self) -> Union[str, None]:
+
+        return self._details
