@@ -10,13 +10,14 @@
 
 import logging
 import os
-import rich_click as click
-import structlog
 import sys
 from pathlib import Path
-from rich.markdown import Markdown
 from typing import Tuple, Union
 
+import rich_click as click
+import structlog
+from rich.markdown import Markdown
+
 from kiara.context.config import KiaraConfig
 from kiara.defaults import (
     KIARA_CONFIG_FILE_NAME,
@@ -24,15 +25,13 @@ from kiara.defaults import (
     SYMLINK_ISSUE_MSG,
 )
 from kiara.interfaces.python_api import KiaraAPI
-from kiara.utils import is_debug
+from kiara.utils import is_debug, log_message
 from kiara.utils.class_loading import find_all_cli_subcommands
 from kiara.utils.cli import terminal_print
 
-# from .service.commands import service
-
-# click.rich_click.USE_MARKDOWN = True
 click.rich_click.USE_RICH_MARKUP = True
 
+logger = structlog.get_logger()
 
 if is_debug():
     structlog.configure(
@@ -43,7 +42,7 @@ else:
         wrapper_class=structlog.make_filtering_bound_logger(logging.WARNING),
     )
 
-CLICK_CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
+CLICK_CONTEXT_SETTINGS = {"help_option_names": ["-h", "--help"]}
 
 
 @click.group(context_settings=CLICK_CONTEXT_SETTINGS)
@@ -67,9 +66,18 @@ CLICK_CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
     multiple=True,
     required=False,
 )
+@click.option(
+    "--plugin",
+    "-P",
+    help="Ensure the provided plugin package(s) are installed in the virtual environment.",
+)
 @click.pass_context
 def cli(
-    ctx, config: Union[str, None], context: Union[str, None], pipelines: Tuple[str]
+    ctx,
+    config: Union[str, None],
+    context: Union[str, None],
+    pipelines: Tuple[str],
+    plugin: Union[str, None],
 ):
     """[i b]kiara[/b i] ia a data-orchestration framework; this is the command-line frontend for it.
 
@@ -132,9 +140,26 @@ def cli(
     if not context:
         context = kiara_config.default_context
 
-    kiara = kiara_config.create_context(context=context, extra_pipelines=pipelines)
-    ctx.obj["kiara"] = kiara
-    ctx.obj["kiara_api"] = KiaraAPI(kiara=kiara)
+    api = KiaraAPI(kiara_config=kiara_config)
+
+    if plugin:
+        installed = api.ensure_plugin_packages(plugin, update=False)
+        if installed:
+            log_message(
+                "replacing.process",
+                reason="reloading this process, in order to pick up new plugin packages",
+            )
+            os.execvp(sys.executable, (sys.executable,) + tuple(sys.argv))  # noqa
+
+    api.set_active_context(context, create=True)
+
+    for pipeline in pipelines:
+        ops = api.context.operation_registry.register_pipelines(pipeline)
+        for op_id in ops.keys():
+            logger.debug("register.pipeline", operation_id=op_id)
+
+    ctx.obj["kiara_api"] = api
+    ctx.obj["kiara"] = api.context
     ctx.obj["kiara_config"] = kiara_config
     ctx.obj["kiara_context_name"] = context
 
