@@ -3,16 +3,16 @@
 #  Copyright (c) 2021, Markus Binsteiner
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
-import rich_click as click
 import sys
-from rich import box
-from rich.panel import Panel
-from rich.table import Table
 from typing import Tuple, Union
 
+import rich_click as click
+from rich.panel import Panel
+
+from kiara import KiaraAPI
 from kiara.context import Kiara, KiaraConfig, KiaraContextConfig
 from kiara.interfaces import get_console
-from kiara.models.context import ContextSummaries, ContextSummary
+from kiara.models.context import ContextInfo, ContextInfos
 from kiara.models.values.value_metadata import ValueMetadata
 from kiara.registries.environment import EnvironmentRegistry
 from kiara.utils.cli import output_format_option, terminal_print, terminal_print_model
@@ -30,16 +30,9 @@ def context(ctx):
 def list_contexts(ctx) -> None:
     """List existing contexts."""
 
-    kiara_config: KiaraConfig = ctx.obj["kiara_config"]
+    kiara_api: KiaraAPI = ctx.obj["kiara_api"]
 
-    table = Table(show_header=True, box=box.SIMPLE)
-    table.add_column("alias", style="b")
-    table.add_column("id", style="i")
-    table.add_column("summary")
-
-    summaries = ContextSummaries.create_context_summaries(
-        contexts=kiara_config.context_configs
-    )
+    summaries = kiara_api.retrieve_context_infos()
 
     terminal_print(summaries)
 
@@ -65,7 +58,7 @@ def explain_context(
     if len(contexts) == 1:
 
         kcc = kiara_config.get_context_config(contexts[0])
-        cs = ContextSummary.create_from_context_config(
+        cs = ContextInfo.create_from_context_config(
             kcc, context_name=contexts[0], runtime_config=kiara_config.runtime_config
         )
         terminal_print_model(
@@ -76,7 +69,7 @@ def explain_context(
         summaries = []
         for c in contexts:
             cc = kiara_config.get_context_config(c)
-            cs = ContextSummary.create_from_context_config(
+            cs = ContextInfo.create_from_context_config(
                 cc, context_name=c, runtime_config=kiara_config.runtime_config
             )
             summaries.append(cs)
@@ -123,7 +116,7 @@ def delete_context(
 
     if _context_name == "ALL_CONTEXTS":
         if not force:
-            summaries = ContextSummaries.create_context_summaries(
+            summaries = ContextInfos.create_context_infos(
                 contexts=kiara_config.context_configs
             )
             terminal_print_model(summaries, in_panel="All contexts:")
@@ -152,7 +145,7 @@ def delete_context(
         if not force:
 
             context_summary = kiara_config.delete(
-                context_name=context_name, dry_run=True
+                context_name=_context_name, dry_run=True
             )
             terminal_print_model(
                 context_summary,
@@ -161,7 +154,7 @@ def delete_context(
             )
             terminal_print()
             user_input = get_console().input(
-                f"Deleting context '[b i]{_context_name}[/b i]', are you sure? \[yes/no]: "  # noqa
+                f"Deleting context '[b i]{_context_name}[/b i]', are you sure? \[yes/no]: "
             )
 
             if user_input.lower() == "yes":
@@ -174,7 +167,7 @@ def delete_context(
             sys.exit(0)
 
         terminal_print("Deleting context...")
-        kiara_config.delete(context_name=context_name, dry_run=False)
+        kiara_config.delete(context_name=_context_name, dry_run=False)
 
         terminal_print("Done.")
 
@@ -206,7 +199,7 @@ def config_help(ctx):
     """Print available configuration options and information about them."""
 
     table = create_table_from_base_model_cls(model_cls=KiaraContextConfig)
-    print()
+    terminal_print()
     terminal_print(Panel(table))
 
 
@@ -308,8 +301,8 @@ def explain_metadata(ctx, metadata_key, format) -> None:
     metadata_types = kiara_obj.kiara_model_registry.get_models_of_type(ValueMetadata)
 
     if metadata_key not in metadata_types.item_infos.keys():
-        print()
-        print(f"No metadata schema for key '{metadata_key}' found...")
+        terminal_print()
+        terminal_print(f"No metadata schema for key '{metadata_key}' found...")
         sys.exit(1)
 
     info_obj = metadata_types.item_infos[metadata_key]
