@@ -7,16 +7,17 @@
 
 """Type-related subcommands for the cli."""
 
-import rich_click as click
 from typing import Dict, Iterable, Type
 
+import rich_click as click
+
 from kiara.context import Kiara
 from kiara.data_types import DataType
 from kiara.interfaces.python_api.models.info import (
     DataTypeClassesInfo,
     DataTypeClassInfo,
 )
-from kiara.utils.cli import output_format_option, terminal_print_model
+from kiara.utils.cli import output_format_option, terminal_print, terminal_print_model
 from kiara.utils.graphs import print_ascii_graph
 
 
@@ -95,7 +96,7 @@ def hierarchy(ctx, include_internal) -> None:
     kiara_obj: Kiara = ctx.obj["kiara"]
 
     type_mgmt = kiara_obj.type_registry
-    print()
+    terminal_print()
 
     if include_internal:
         print_ascii_graph(type_mgmt.data_type_hierarchy)
