@@ -1,23 +1,8 @@
 # -*- coding: utf-8 -*-
 import abc
-import humanfriendly
 import inspect
-import orjson
 import textwrap
 import uuid
-from pydantic import BaseModel, Field, PrivateAttr, validator
-from pydantic.schema import (
-    get_flat_models_from_model,
-    get_model_name_map,
-    model_process_schema,
-)
-from rich import box
-from rich.console import RenderableType
-from rich.markdown import Markdown
-from rich.panel import Panel
-from rich.syntax import Syntax
-from rich.table import Table
-from rich.tree import Tree
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -33,6 +18,22 @@ from typing import (
     Union,
 )
 
+import humanfriendly
+import orjson
+from pydantic import BaseModel, Field, PrivateAttr, validator
+from pydantic.schema import (
+    get_flat_models_from_model,
+    get_model_name_map,
+    model_process_schema,
+)
+from rich import box
+from rich.console import RenderableType
+from rich.markdown import Markdown
+from rich.panel import Panel
+from rich.syntax import Syntax
+from rich.table import Table
+from rich.tree import Tree
+
 from kiara.defaults import DEFAULT_NO_DESC_VALUE
 from kiara.models import KiaraModel
 from kiara.models.documentation import (
@@ -62,6 +63,7 @@ from kiara.models.values.value import (
 )
 from kiara.models.values.value_schema import ValueSchema
 from kiara.modules import KiaraModule
+from kiara.renderers import KiaraRenderer
 from kiara.utils import log_exception, log_message
 from kiara.utils.class_loading import find_all_kiara_model_classes
 from kiara.utils.json import orjson_dumps
@@ -257,7 +259,8 @@ class InfoItemGroup(KiaraModel, Generic[INFO_ITEM_TYPE]):
 
         info_cls = cls.base_info_class()
         items = {}
-        for k, v in instances.items():
+        for k in sorted(instances.keys()):
+            v = instances[k]
             items[k] = info_cls.create_from_instance(kiara=kiara, instance=v, **kwargs)
 
         group_title = kwargs.pop("group_title", None)
@@ -1013,7 +1016,8 @@ class ModuleTypeInfo(TypeInfo[Type["KiaraModule"]]):
 
         if not hasattr(module_cls, "process"):
             raise Exception(f"Module class '{module_cls}' misses 'process' method.")
-        proc_src = textwrap.dedent(inspect.getsource(module_cls.process))  # type: ignore
+
+        module_src = textwrap.dedent(inspect.getsource(module_cls))  # type: ignore
 
         authors_md = AuthorsMetadataModel.from_class(module_cls)
         doc = DocumentationMetadataModel.from_class_doc(module_cls)
@@ -1028,10 +1032,10 @@ class ModuleTypeInfo(TypeInfo[Type["KiaraModule"]]):
             "context": properties_md,
             "python_class": python_class,
             "config": config,
-            "process_src": proc_src,
+            "module_src": module_src,
         }
 
-    process_src: str = Field(
+    module_src: str = Field(
         description="The source code of the process method of the module."
     )
 
@@ -1067,7 +1071,7 @@ class ModuleTypeInfo(TypeInfo[Type["KiaraModule"]]):
             from kiara.context.config import KIARA_SETTINGS
 
             _config = Syntax(
-                self.process_src,
+                self.module_src,
                 "python",
                 background_color=KIARA_SETTINGS.syntax_highlight_background,
             )
@@ -1105,13 +1109,11 @@ class OperationTypeInfo(TypeInfo[Type["OperationType"]]):
         properties_md = ContextMetadataModel.from_class(type_cls)
 
         return OperationTypeInfo.construct(
-            **{
-                "type_name": type_cls._operation_type_name,  # type: ignore
-                "documentation": doc,
-                "authors": authors_md,
-                "context": properties_md,
-                "python_class": python_class,
-            }
+            type_name=type_cls._operation_type_name,  # type: ignore
+            documentation=doc,
+            authors=authors_md,
+            context=properties_md,
+            python_class=python_class,
         )
 
     @classmethod
@@ -1387,7 +1389,8 @@ class OperationInfo(ItemInfo):
 
     def create_renderable(self, **config: Any) -> RenderableType:
 
-        include_doc = config.get("include_doc", True)
+        include_doc = config.get("include_doc", False)
+        include_op_details = config.get("include_op_details", True)
 
         table = Table(box=box.SIMPLE, show_header=False, padding=(0, 0, 0, 0))
         table.add_column("property", style="i")
@@ -1401,7 +1404,10 @@ class OperationInfo(ItemInfo):
         table.add_row("Author(s)", self.authors.create_renderable(**config))
         table.add_row("Context", self.context.create_renderable(**config))
 
-        table.add_row("Operation details", self.operation.create_renderable(**config))
+        if include_op_details:
+            table.add_row(
+                "Operation details", self.operation.create_renderable(**config)
+            )
         return table
 
 
@@ -1422,6 +1428,7 @@ class OperationGroupInfo(InfoItemGroup):
             k: OperationInfo.create_from_operation(kiara=kiara, operation=v)
             for k, v in items.items()
         }
+
         op_group_info = cls.construct(group_title=group_title, item_infos=op_infos)
         return op_group_info
 
@@ -1551,3 +1558,122 @@ class OperationGroupInfo(InfoItemGroup):
                 first_line_value = False
 
         return table
+
+
+class RendererInfo(ItemInfo[KiaraRenderer]):
+
+    renderer_config: Mapping[str, Any] = Field(description="The renderer config.")
+    renderer_cls: PythonClass = Field(
+        description="The Python class that implements the renderer."
+    )
+    supported_inputs: List[str] = Field(
+        description="Descriptions of the supported inputs."
+    )
+    supported_source_types: List[str] = Field(
+        description="Descriptions of the supported source types."
+    )
+    supported_target_types: List[str] = Field(
+        description="Descriptions of the supported target types."
+    )
+    supported_python_classes: List[PythonClass] = Field(
+        description="A list of supported Python types that are acceptable as inputs."
+    )
+
+    @classmethod
+    def base_instance_class(cls) -> Type[KiaraRenderer]:
+        return KiaraRenderer
+
+    @classmethod
+    def create_from_instance(cls, kiara: "Kiara", instance: KiaraRenderer, **kwargs):
+
+        doc = instance.doc
+        authors = AuthorsMetadataModel.from_class(instance.__class__)
+        properties_md = ContextMetadataModel.from_class(instance.__class__)
+
+        renderer_name = instance._renderer_name  # type: ignore
+        renderer_config = instance.renderer_config.dict()
+        renderer_cls = PythonClass.from_class(item_cls=instance.__class__)
+        supported_inputs = list(instance.supported_inputs_descs)
+        supported_python_classes = [
+            PythonClass.from_class(x)
+            for x in instance.retrieve_supported_python_classes()
+        ]
+
+        supported_input_types = instance.retrieve_supported_render_sources()
+        if isinstance(supported_input_types, str):
+            supported_input_types = [supported_input_types]
+        supported_target_types = instance.retrieve_supported_render_targets()
+        if isinstance(supported_target_types, str):
+            supported_target_types = [supported_target_types]
+
+        return cls(
+            type_name=renderer_name,
+            documentation=doc,
+            authors=authors,
+            context=properties_md,
+            renderer_config=renderer_config,
+            renderer_cls=renderer_cls,
+            supported_inputs=supported_inputs,
+            supported_python_classes=supported_python_classes,
+            supported_source_types=supported_input_types,
+            supported_target_types=supported_target_types,
+        )
+
+    def create_renderable(self, **config: Any) -> RenderableType:
+
+        show_metadata = config.get("show_metadata", False)
+
+        table = Table(box=box.SIMPLE, show_header=False)
+        table.add_column("key", style="i")
+        table.add_column("value")
+
+        table.add_row("Documentation", self.documentation.create_renderable(**config))
+        inputs_md = ""
+        for inp in self.supported_inputs:
+            inputs_md += f"- {inp}\n"
+        table.add_row("Supported inputs", Markdown(inputs_md))
+
+        if show_metadata:
+            table.add_row("Renderer name", self.type_name)
+            if self.renderer_config:
+                json = orjson_dumps(self.renderer_config, option=orjson.OPT_INDENT_2)
+                table.add_row(
+                    "Renderer config", Syntax(json, "json", background_color="default")
+                )
+
+            table.add_row(
+                "Renderer class", self.renderer_cls.create_renderable(**config)
+            )
+            table.add_row("Author(s)", self.authors.create_renderable(**config))
+            table.add_row("Context", self.context.create_renderable(**config))
+
+        python_cls_md = ""
+        for inp_cls in self.supported_python_classes:
+            python_cls_md += f"- {inp_cls.full_name}\n"
+        table.add_row(python_cls_md)
+
+        return table
+
+
+class RendererInfos(InfoItemGroup[RendererInfo]):
+    @classmethod
+    def base_info_class(cls) -> Type[RendererInfo]:
+        return RendererInfo
+
+    def create_renderable(self, **config: Any) -> RenderableType:
+
+        table = Table(show_header=True, box=box.SIMPLE, show_lines=True)
+        table.add_column("Source type(s)")
+        table.add_column("Target type(s)")
+        table.add_column("Description")
+
+        for info in self.item_infos.values():
+            row: List[RenderableType] = []
+
+            row.append("\n".join(info.supported_source_types))  # type: ignore
+            row.append("\n".join(info.supported_target_types))  # type: ignore
+            row.append(info.documentation.create_renderable(**config))
+
+            table.add_row(*row)
+
+        return table
