@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
-from pydantic import BaseModel, Field
 from typing import Any, Dict
 
+from pydantic import BaseModel, Field
+
 from kiara.context import Kiara
 from kiara.models.module.jobs import JobConfig
 from kiara.models.module.manifest import Manifest
@@ -21,7 +22,7 @@ class JobDesc(BaseModel):
         manifest = Manifest(
             module_type=self.module_type, module_config=self.module_config
         )
-        module = kiara.create_module(manifest=manifest)
+        module = kiara.module_registry.create_module(manifest=manifest)
         job_config = JobConfig.create_from_module(
             data_registry=kiara.data_registry, module=module, inputs=self.inputs
         )
