@@ -1,17 +1,18 @@
 # -*- coding: utf-8 -*-
-import pytz
-import structlog
 import uuid
 from datetime import datetime
-from slugify import slugify
-from typing import TYPE_CHECKING, Any, Dict, List, Mapping, Set, Tuple, Union
+from typing import TYPE_CHECKING, Any, Dict, Hashable, List, Mapping, Set, Tuple, Union
+
+import pytz
+import structlog
+from boltons.strutils import slugify
 
 from kiara.defaults import NONE_VALUE_ID, NOT_SET_VALUE_ID
 from kiara.exceptions import NoSuchWorkflowException
 from kiara.models import KiaraModel
 from kiara.models.documentation import DocumentationMetadataModel
 from kiara.models.events.pipeline import ChangedValue, PipelineEvent
-from kiara.models.module.jobs import ExecutionContext, JobConfig
+from kiara.models.module.jobs import ActiveJob, ExecutionContext, JobConfig, JobStatus
 from kiara.models.module.manifest import Manifest
 from kiara.models.module.pipeline import (
     PipelineConfig,
@@ -23,7 +24,7 @@ from kiara.models.module.pipeline import (
 from kiara.models.module.pipeline.controller import SinglePipelineController
 from kiara.models.module.pipeline.pipeline import Pipeline, PipelineInfo
 from kiara.models.python_class import KiaraModuleInstance
-from kiara.models.values.value import ValueMap
+from kiara.models.values.value import Value, ValueMap
 from kiara.models.values.value_schema import ValueSchema
 from kiara.models.workflow import WorkflowInfo, WorkflowMetadata, WorkflowState
 from kiara.registries.ids import ID_REGISTRY
@@ -41,9 +42,6 @@ class WorkflowPipelineController(SinglePipelineController):
     This is the default implementation of a ``PipelineController``, and probably the most simple implementation of one.
     It waits until all inputs are set, after which it executes all pipeline steps in the required order.
 
-    Arguments:
-        pipeline: the pipeline to control
-        auto_process: whether to automatically start processing the pipeline as soon as the input set is valid
     """
 
     def __init__(
@@ -61,7 +59,9 @@ class WorkflowPipelineController(SinglePipelineController):
 
         self._pipeline_details = None
 
-    def process_pipeline(self) -> Mapping[uuid.UUID, uuid.UUID]:
+    def process_pipeline(
+        self,
+    ) -> Tuple[Mapping[uuid.UUID, uuid.UUID], Mapping[str, ActiveJob]]:
 
         log = logger.bind(pipeline_id=self.pipeline.pipeline_id)
         if self._is_running:
@@ -75,6 +75,8 @@ class WorkflowPipelineController(SinglePipelineController):
         self._is_running = True
 
         result: Dict[uuid.UUID, uuid.UUID] = {}
+        errors: Dict[str, ActiveJob] = {}
+
         try:
             for idx, stage in enumerate(
                 self.pipeline.structure.processing_stages, start=1
@@ -101,12 +103,17 @@ class WorkflowPipelineController(SinglePipelineController):
                         # TODO: cancel running jobs?
                         log_exception(e)
                         log.error(
-                            "error.processing.pipeline",
+                            "error.processing.workflow_pipeline",
                             step_id=step_id,
                             error=e,
                         )
                         stage_failed = True
 
+                self._job_registry.wait_for(*job_ids.values())
+                for step_id, job_id in job_ids.items():
+                    j = self._job_registry.get_job(job_id)
+                    if j.status != JobStatus.SUCCESS:
+                        errors[step_id] = j
                 output_job_map = self.set_processing_results(job_ids=job_ids)
                 result.update(output_job_map)
                 if not stage_failed:
@@ -126,7 +133,7 @@ class WorkflowPipelineController(SinglePipelineController):
             self._is_running = False
 
         log.debug("execute_finished.pipeline")
-        return result
+        return result, errors
 
 
 class WorkflowStatus(KiaraModel):
@@ -334,7 +341,8 @@ class Workflow(object):
             WorkflowPipelineController(kiara=self._kiara)
         )
 
-        self._all_inputs: Dict[str, Any] = {}
+        self._all_inputs: Dict[str, Union[None, uuid.UUID]] = {}
+        self._all_inputs_optimistic_lookup: Dict[str, Dict[Hashable, uuid.UUID]] = {}
         self._current_pipeline_inputs: Union[Dict[str, uuid.UUID], None] = None
         self._current_pipeline_outputs: Union[Dict[str, uuid.UUID], None] = None
 
@@ -458,6 +466,12 @@ class Workflow(object):
     def output_aliases(self) -> Mapping[str, str]:
         return self._workflow_output_aliases
 
+    def clear_current_inputs_for_step(self, step_id):
+
+        fields = self.get_current_inputs_schema_for_step(step_id)
+        for field in fields.keys():
+            self.set_inputs(**{k: None for k in fields.keys()})
+
     @property
     def current_inputs_schema(self) -> Mapping[str, ValueSchema]:
 
@@ -474,6 +488,20 @@ class Workflow(object):
         self._current_workflow_inputs_schema = temp
         return self._current_workflow_inputs_schema
 
+    def get_current_inputs_schema_for_step(
+        self, step_id: str
+    ) -> Mapping[str, ValueSchema]:
+        return self.pipeline.structure.get_pipeline_inputs_schema_for_step(
+            step_id=step_id
+        )
+
+    def get_current_outputs_schema_for_step(
+        self, step_id: str
+    ) -> Mapping[str, ValueSchema]:
+        return self.pipeline.structure.get_pipeline_outputs_schema_for_step(
+            step_id=step_id
+        )
+
     @property
     def current_input_names(self) -> List[str]:
         return sorted(self.current_inputs_schema.keys())
@@ -591,8 +619,8 @@ class Workflow(object):
 
         inputs_to_set = {}
         for field_name, value in self._all_inputs.items():
-            if value in [NONE_VALUE_ID, NOT_SET_VALUE_ID]:
-                continue
+            # if value in [None, NONE_VALUE_ID, NOT_SET_VALUE_ID]:
+            #     continue
             if field_name in pipeline.structure.pipeline_inputs_schema.keys():
                 inputs_to_set[field_name] = value
 
@@ -641,12 +669,14 @@ class Workflow(object):
         self._pipeline_info = None
         return changed
 
-    def process_steps(self, *step_ids: str):
+    def process_steps(
+        self, *step_ids: str
+    ) -> Tuple[Mapping[uuid.UUID, uuid.UUID], Mapping[str, ActiveJob]]:
 
-        self.pipeline  # noqa
+        self.pipeline
 
         if not step_ids:
-            output_job_map = self._pipeline_controller.process_pipeline()
+            output_job_map, errors = self._pipeline_controller.process_pipeline()
         else:
             job_ids = {}
             for step_id in step_ids:
@@ -654,6 +684,13 @@ class Workflow(object):
                     step_id=step_id, wait=True
                 )
                 job_ids[step_id] = job_id
+
+            self._pipeline_controller._job_registry.wait_for(*job_ids.values())
+            errors = {}
+            for step_id, job_id in job_ids.items():
+                j = self._pipeline_controller._job_registry.get_job(job_id)
+                if j.status != JobStatus.SUCCESS:
+                    errors[step_id] = j
             output_job_map = self._pipeline_controller.set_processing_results(
                 job_ids=job_ids
             )
@@ -665,6 +702,8 @@ class Workflow(object):
         self._pipeline_info = None
         self._current_info = None
 
+        return output_job_map, errors
+
     def _invalidate_pipeline(self):
 
         self._pipeline_controller.pipeline = None
@@ -672,15 +711,39 @@ class Workflow(object):
         self._pipeline_info = None
         self._current_info = None
         self._current_state = None
+        self._current_workflow_inputs_schema = None
+        self._current_workflow_outputs_schema = None
+        self._current_pipeline_inputs = None
+        self._current_pipeline_outputs = None
 
-    def set_input(self, field_name: str, value: Any):
+    def set_input(self, field_name: str, value: Any) -> Union[None, uuid.UUID]:
+        """Set a single pipeline input.
 
-        self.set_inputs(**{field_name: value})
+        Arguments:
+            field_name: The name of the input field.
+            value: The value to set.
 
-    def set_inputs(self, **inputs: Any):
+        Returns:
+            None if the value for that field in the pipeline didn't change, otherwise the value_id of the new (registered) value.
+
+        """
+
+        diff = self.set_inputs(**{field_name: value})
+        return diff.get(field_name, None)
+
+    def set_inputs(self, **inputs: Any) -> Dict[str, Union[uuid.UUID, None]]:
+        """Set multiple pipeline inputs, at once.
+
+        Arguments:
+            inputs: The inputs to set.
+
+        Returns:
+            a dict containing only the newly set or changed values with field name as keys, and value_id (or None) as values.
+        """
 
         _inputs = {}
         for k, v in inputs.items():
+            # translate aliases
             match = False
             for field, alias in self._workflow_input_aliases.items():
                 if k == alias:
@@ -701,15 +764,80 @@ class Workflow(object):
                 f"Can't set pipeline inputs, invalid field(s): {', '.join(invalid)}. Available inputs: '{', '.join(self.pipeline.structure.pipeline_inputs_schema.keys())}'"
             )
 
-        changed = False
-        for k, v in inputs.items():
-            # TODO: better equality test?
-            if k == self._all_inputs.get(k, None):
-                continue
-            self._all_inputs[k] = v
-            changed = True
+        diff: Dict[str, Union[None, uuid.UUID]] = {}
+        for k, val_new in inputs.items():
 
-        if changed:
+            val_old = self._all_inputs.get(k, None)
+            if val_old is None and val_new is None:
+                continue
+
+            if val_new is None:
+                self._all_inputs[k] = None
+                diff[k] = None
+                continue
+
+            if isinstance(val_new, uuid.UUID):
+                if val_new == val_old:
+                    continue
+                else:
+                    self._all_inputs[k] = val_new
+                    diff[k] = val_new
+                    continue
+
+            if isinstance(val_new, Value):
+                if val_new.value_id == val_old:
+                    continue
+                else:
+                    self._all_inputs[k] = val_new.value_id
+                    diff[k] = val_new.value_id
+                    continue
+
+            # TODO: check for aliases?
+            try:
+                _new_item_hash = hash(val_new)
+
+                _match: Union[None, uuid.UUID] = None
+                for _item_hash, _value_id in self._all_inputs_optimistic_lookup.get(
+                    k, {}
+                ).items():
+                    if _item_hash == _new_item_hash:
+                        if _value_id == val_old:
+                            _match = val_old
+                            break
+
+                if not _match:
+                    _schema = self.current_pipeline_inputs_schema[k]
+                    val = self._kiara.data_registry.register_data(
+                        data=val_new, schema=_schema, reuse_existing=True
+                    )
+                    _match = val.value_id
+                    self._all_inputs_optimistic_lookup.setdefault(k, {})[
+                        _new_item_hash
+                    ] = _match
+
+                if _match == val_old:
+                    continue
+                else:
+                    self._all_inputs[k] = _match
+                    diff[k] = _match
+                    continue
+
+            except Exception:
+                # value can't be hashed, so we have to accept we can not re-use an existing value for this
+                _schema = self.current_pipeline_inputs_schema[k]
+                val = self._kiara.data_registry.register_data(
+                    data=val_new, schema=_schema, reuse_existing=True
+                )
+                new_value_id = val.value_id
+                if new_value_id == val_old:
+                    continue
+                else:
+                    self._all_inputs[k] = new_value_id
+                    diff[k] = new_value_id
+
+        self._all_inputs.update(diff)
+
+        if diff:
             self._current_info = None
             self._current_state = None
             self._current_pipeline_inputs = None
@@ -719,6 +847,8 @@ class Workflow(object):
             self._pipeline_info = None
             self._apply_inputs()
 
+        return diff
+
     def add_steps(
         self,
         *pipeline_steps: Union[PipelineStep, Mapping[str, Any]],
@@ -807,6 +937,20 @@ class Workflow(object):
         self.workflow_metadata.output_aliases[output_field] = alias
         self._metadata_is_synced = False
 
+    # def remove_step(self, step_id: str):
+    #
+    #     if step_id not in self._steps.keys():
+    #         raise Exception(f"Can't remove step, no step with id '{step_id}'.")
+    #
+    #     del_step = self._steps[step_id]
+    #     for step_id, step in self._steps.items():
+    #         for input_field, links in step.input_links.items():
+    #             for link in links:
+    #                 if link.step_id == del_step.step_id:
+    #                     links.remove(link)
+    #
+    #     self._invalidate_pipeline()
+
     def add_step(
         self,
         operation: str,
@@ -830,7 +974,7 @@ class Workflow(object):
 
         if step_id is None:
             step_id = find_free_id(
-                slugify(operation, separator="_"), current_ids=self._steps.keys()
+                slugify(operation, delim="_"), current_ids=self._steps.keys()
             )
 
         if "." in step_id:
@@ -846,7 +990,7 @@ class Workflow(object):
         manifest = self._kiara.create_manifest(
             module_or_operation=operation, config=module_config
         )
-        module = self._kiara.create_module(manifest=manifest)
+        module = self._kiara.module_registry.create_module(manifest=manifest)
         manifest_src = Manifest(
             module_type=manifest.module_type, module_config=manifest.module_config
         )
