@@ -5,10 +5,12 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
+from abc import ABC
+from typing import Any, ClassVar, Dict, Iterable, List, Mapping, Union
+
 import networkx as nx
 import orjson
-from abc import ABC
-from dag_cbor.encoding import EncodableType
+from dag_cbor import Kind
 from deepdiff import DeepHash
 from multiformats import CID
 from pydantic import Extra
@@ -20,7 +22,6 @@ from rich.jupyter import JupyterMixin
 from rich.panel import Panel
 from rich.table import Table
 from rich.tree import Tree
-from typing import Any, ClassVar, Dict, Iterable, List, Mapping, Union
 
 from kiara.defaults import KIARA_HASH_FUNCTION
 from kiara.registries.templates import TemplateRegistry
@@ -75,7 +76,7 @@ class KiaraModel(ABC, BaseModel, JupyterMixin):
     _dag_cache: Union[bytes, None] = PrivateAttr(default=None)
     _size_cache: Union[int, None] = PrivateAttr(default=None)
 
-    def _retrieve_data_to_hash(self) -> EncodableType:
+    def _retrieve_data_to_hash(self) -> Kind:
         """Return data important for hashing this model instance. Implemented by sub-classes.
 
         This returns the relevant data that makes this model unique, excluding any secondary metadata that is not
@@ -310,7 +311,7 @@ class KiaraModel(ABC, BaseModel, JupyterMixin):
         return self.__repr__()
 
     def _repr_html_(self):
-        return self.create_html()
+        return str(self.create_html())
 
     def __rich_console__(
         self, console: Console, options: ConsoleOptions
