@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
-import humanfriendly
 import uuid
+from typing import TYPE_CHECKING, Any, Dict, List, Mapping, Union
+
+import humanfriendly
 from humanfriendly import format_size
 from pydantic import BaseModel, Field, PrivateAttr
 from rich import box
 from rich.console import Group, RenderableType
 from rich.markdown import Markdown
 from rich.table import Table
-from typing import TYPE_CHECKING, Any, Dict, List, Mapping, Union
 
 from kiara.context import KiaraConfig, KiaraContextConfig, KiaraRuntimeConfig
 from kiara.models import KiaraModel
@@ -17,7 +18,7 @@ if TYPE_CHECKING:
     from kiara.context import Kiara
 
 
-class ContextSummary(KiaraModel):
+class ContextInfo(KiaraModel):
     @classmethod
     def create_from_context_config(
         cls,
@@ -63,7 +64,7 @@ class ContextSummary(KiaraModel):
             for k, err in errors.items():
                 comment = f"{comment}  - {k}: {err}"
 
-        result = ContextSummary.construct(
+        result = ContextInfo.construct(
             kiara_id=kiara.id,
             value_ids=value_ids,
             aliases=aliases,
@@ -230,11 +231,11 @@ class ContextSummary(KiaraModel):
         return table
 
 
-class ContextSummaries(BaseModel):
-    __root__: Dict[str, ContextSummary]
+class ContextInfos(BaseModel):
+    __root__: Dict[str, ContextInfo]
 
     @classmethod
-    def create_context_summaries(
+    def create_context_infos(
         cls, contexts: Union[Mapping[str, "KiaraContextConfig"], None] = None
     ):
 
@@ -242,9 +243,9 @@ class ContextSummaries(BaseModel):
             kc = KiaraConfig()
             contexts = kc.context_configs
 
-        return ContextSummaries(
+        return ContextInfos(
             __root__={
-                a: ContextSummary.create_from_context_config(c, context_name=a)
+                a: ContextInfo.create_from_context_config(c, context_name=a)
                 for a, c in contexts.items()
             }
         )
