@@ -7,16 +7,17 @@
 import atexit
 import os
 import shutil
-import structlog
 import tempfile
+from pathlib import Path
+from typing import Any, Dict, List, Mapping, Union
+
+import structlog
 from deepdiff import DeepHash
 from multiformats import CID
-from pathlib import Path
 from pydantic import BaseModel, Field, PrivateAttr
 from rich import box
 from rich.console import RenderableType
 from rich.table import Table
-from typing import Any, Dict, List, Mapping, Union
 
 from kiara.defaults import DEFAULT_EXCLUDE_FILES, KIARA_HASH_FUNCTION
 from kiara.models import KiaraModel
@@ -48,10 +49,11 @@ class FileModel(KiaraModel):
         file_name: Union[str, None] = None,
         # import_time: Optional[datetime.datetime] = None,
     ):
-        """Utility method to read metadata of a file from disk and optionally move it into a data archive location."""
+        """Utility method to read metadata of a file from disk."""
+
+        import mimetypes
 
         import filetype
-        import mimetypes
 
         if not source:
             raise ValueError("No source path provided.")
@@ -99,6 +101,10 @@ class FileModel(KiaraModel):
     mime_type: str = Field(description="The mime type of the file.")
     file_name: str = Field("The name of the file.")
     size: int = Field(description="The size of the file.")
+    metadata: Dict[str, Any] = Field(
+        description="Additional, ustructured, user-defined metadata.",
+        default_factory=dict,
+    )
 
     _path: Union[str, None] = PrivateAttr(default=None)
     _file_hash: Union[str, None] = PrivateAttr(default=None)
@@ -359,6 +365,11 @@ class FileBundle(KiaraModel):
         description="A map of all the included files, incl. their properties. Uses the relative path of each file as key."
     )
     size: int = Field(description="The size of all files in this folder, combined.")
+    metadata: Dict[str, Any] = Field(
+        description="Additional, ustructured, user-defined metadata.",
+        default_factory=dict,
+    )
+
     _path: Union[str, None] = PrivateAttr(default=None)
 
     @property
@@ -498,7 +509,7 @@ class FileBundle(KiaraModel):
             files = list(self.included_files.keys())
             half = int((max_no_included_files - 1) / 2)
             head = files[0:half]
-            tail = files[-1 * half :]  # noqa
+            tail = files[-1 * half :]
             for rel_path in head:
                 model = self.included_files[rel_path]
                 row = [rel_path, str(model.size)]
