@@ -6,6 +6,8 @@
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
 import abc
+from typing import TYPE_CHECKING, Any, Dict, Iterable, Mapping, Union
+
 import orjson
 import structlog
 from pydantic import Field, PrivateAttr, validator
@@ -13,7 +15,6 @@ from rich import box
 from rich.console import Group, RenderableType
 from rich.syntax import Syntax
 from rich.table import Table
-from typing import TYPE_CHECKING, Any, Dict, Iterable, Mapping, Union
 
 from kiara.defaults import PYDANTIC_USE_CONSTRUCT
 from kiara.models import KiaraModel
@@ -207,7 +208,7 @@ class PipelineOperationConfig(OperationConfig):
 
     def __repr__(self):
 
-        return f"{self.__class__.__name__}(pipeline_name={self.pipeline_name} required_modules={list(self.required_module_types)} instance_id={self.instance_id}, category={self.model_type_d}, fields=[{', '.join(self.__fields__.keys())}])"
+        return f"{self.__class__.__name__}(pipeline_name={self.pipeline_name} required_modules={list(self.required_module_types)} instance_id={self.instance_id} fields=[{', '.join(self.__fields__.keys())}])"
 
 
 class Operation(Manifest):
@@ -312,7 +313,7 @@ class Operation(Manifest):
         )
         return job_config
 
-    def run(self, kiara: "Kiara", inputs: Any) -> ValueMap:
+    def run(self, kiara: "Kiara", inputs: Mapping[str, Any]) -> ValueMap:
 
         logger.debug("run.operation", operation_id=self.operation_id)
         job_config = self.prepare_job_config(kiara=kiara, inputs=inputs)
@@ -428,7 +429,7 @@ class Operation(Manifest):
             table.add_row("Module metadata", m_md)
 
         if include_src:
-            table.add_row("Source code", module_type_md.process_src)
+            table.add_row("Source code", module_type_md.module_src)
 
         return table
 
