@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
-
-#  Copyright (c) 2021, Markus Binsteiner
-#
-#  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
+import os
+import uuid
+from enum import Enum
+from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Union
 
 import orjson
-import os
-from enum import Enum
+from boltons.strutils import slugify
 from pydantic import Extra, Field, PrivateAttr, root_validator, validator
 from rich import box
 from rich.console import RenderableType
@@ -14,9 +13,8 @@ from rich.markdown import Markdown
 from rich.panel import Panel
 from rich.syntax import Syntax
 from rich.table import Table
-from slugify import slugify
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Union
 
+from kiara.exceptions import InvalidPipelineStepConfig
 from kiara.models.documentation import DocumentationMetadataModel
 from kiara.models.module import KiaraModuleConfig
 from kiara.models.module.jobs import ExecutionContext
@@ -31,6 +29,11 @@ from kiara.utils.output import create_table_from_field_schemas
 from kiara.utils.pipelines import ensure_step_value_addresses
 from kiara.utils.string_vars import replace_var_names_in_obj
 
+#  Copyright (c) 2021, Markus Binsteiner
+#
+#  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
+
+
 if TYPE_CHECKING:
     from kiara.context import Kiara
     from kiara.models.module.pipeline.structure import PipelineStructure
@@ -77,8 +80,11 @@ class PipelineStep(Manifest):
         if not isinstance(step, PipelineStep):
 
             module_type = step.get("module_type", None)
+
             if not module_type:
-                raise ValueError("Can't create step, no 'module_type' specified.")
+                raise InvalidPipelineStepConfig(
+                    "Can't create step, no 'module_type' specified.", step_config=step
+                )
 
             module_config = step.get("module_config", {})
 
@@ -107,7 +113,9 @@ class PipelineStep(Manifest):
                         config=resolved_module_config,
                     )
                 else:
-                    raise Exception(f"Can't resolve module type: {module_type}")
+                    raise InvalidPipelineStepConfig(
+                        f"Can't resolve module type: {module_type}", step_config=step
+                    )
             else:
                 manifest = kiara.create_manifest(
                     module_or_operation=module_type, config=module_config
@@ -115,15 +123,19 @@ class PipelineStep(Manifest):
                 resolved_module_type = module_type
                 resolved_module_config = module_config
 
-            module = kiara.create_module(manifest=manifest)
+            module = kiara.module_registry.create_module(manifest=manifest)
 
             step_id = step.get("step_id", None)
             if not step_id:
                 if not auto_step_id:
-                    raise ValueError("Can't create step, no 'step_id' specified.")
+                    raise InvalidPipelineStepConfig(
+                        "Can't create step, no 'step_id' specified in config.",
+                        step_config=step,
+                    )
+
                 else:
                     step_id = find_free_id(
-                        slugify(manifest.module_type, separator="_"),
+                        slugify(manifest.module_type, delim="_"),
                         current_ids=taken_step_ids,
                     )
 
@@ -206,6 +218,7 @@ class PipelineStep(Manifest):
     manifest_src: Manifest = Field(
         description="The original manfifest provided by the user."
     )
+
     # required: bool = Field(
     #     description="Whether this step is required within the workflow.\n\nIn some cases, when none of the pipeline outputs have a required input that connects to a step, then it is not necessary for this step to have been executed, even if it is placed before a step in the execution hierarchy. This also means that the pipeline inputs that are connected to this step might not be required.",
     #     default=True,
@@ -232,7 +245,7 @@ class PipelineStep(Manifest):
         if "module_type" not in values:
             raise ValueError("No 'module_type' specified.")
         if "step_id" not in values or not values["step_id"]:
-            values["step_id"] = slugify(values["module_type"], separator="_")
+            values["step_id"] = slugify(values["module_type"], delim="_")
 
         return values
 
@@ -460,19 +473,24 @@ class PipelineConfig(KiaraModuleConfig):
         cls,
         path: str,
         kiara: Union["Kiara", None] = None,
+        pipeline_name: Union[None, str] = None,
         # module_map: Optional[Mapping[str, Any]] = None,
     ):
 
         data = get_data_from_file(path)
-        pipeline_name = data.pop("pipeline_name", None)
-        if pipeline_name is None:
-            pipeline_name = os.path.basename(path)
+        _pipeline_name = data.pop("pipeline_name", None)
+
+        if pipeline_name:
+            _pipeline_name = pipeline_name
+
+        if _pipeline_name is None:
+            _pipeline_name = os.path.basename(path)
 
         pipeline_dir = os.path.abspath(os.path.dirname(path))
 
         execution_context = ExecutionContext(pipeline_dir=pipeline_dir)
         return cls.from_config(
-            pipeline_name=pipeline_name,
+            pipeline_name=_pipeline_name,
             data=data,
             kiara=kiara,
             execution_context=execution_context,
@@ -481,8 +499,8 @@ class PipelineConfig(KiaraModuleConfig):
     @classmethod
     def from_config(
         cls,
-        pipeline_name: str,
         data: Mapping[str, Any],
+        pipeline_name: Union[str, None] = None,
         kiara: Union["Kiara", None] = None,
         module_map: Union[Mapping[str, Any], None] = None,
         execution_context: Union[ExecutionContext, None] = None,
@@ -495,7 +513,7 @@ class PipelineConfig(KiaraModuleConfig):
             kiara = Kiara.instance()
 
         if not kiara.operation_registry.is_initialized:
-            kiara.operation_registry.operations  # noqa
+            kiara.operation_registry.operations
 
         if execution_context is None:
             execution_context = ExecutionContext()
@@ -513,9 +531,9 @@ class PipelineConfig(KiaraModuleConfig):
     @classmethod
     def _from_config(
         cls,
-        pipeline_name: str,
         data: Mapping[str, Any],
         kiara: "Kiara",
+        pipeline_name: Union[str, None] = None,
         module_map: Union[Mapping[str, Any], None] = None,
         execution_context: Union[ExecutionContext, None] = None,
         auto_step_ids: bool = False,
@@ -527,6 +545,14 @@ class PipelineConfig(KiaraModuleConfig):
         repl_dict = execution_context.dict()
 
         data = dict(data)
+
+        _pipeline_name = data.pop("pipeline_name", None)
+        if pipeline_name:
+            _pipeline_name = pipeline_name
+
+        if not _pipeline_name:
+            _pipeline_name = str(uuid.uuid4())
+
         _steps = data.pop("steps")
         steps = PipelineStep.create_steps(
             *_steps, kiara=kiara, module_map=module_map, auto_step_ids=auto_step_ids
@@ -552,8 +578,10 @@ class PipelineConfig(KiaraModuleConfig):
             replaced = replace_var_names_in_obj(inputs, repl_dict=repl_dict)
             data["inputs"] = replaced
 
-        result = cls(pipeline_name=pipeline_name, **data)
+        if "doc" not in data.keys():
+            data["doc"] = None
 
+        result = cls(pipeline_name=_pipeline_name, **data)
         return result
 
     class Config:
@@ -608,6 +636,31 @@ class PipelineConfig(KiaraModuleConfig):
         self._structure = PipelineStructure(pipeline_config=self)  # type: ignore
         return self._structure
 
+    def get_raw_config(self) -> Dict[str, Any]:
+
+        steps = []
+        for step in self.steps:
+            src: Dict[str, Any] = {
+                "module_type": step.manifest_src.module_type,
+            }
+            if step.manifest_src.module_config:
+                src["module_config"] = step.manifest_src.module_config
+            src["step_id"] = step.step_id
+            for field, links in step.input_links.items():
+                for link in links:
+                    src.setdefault("input_links", {})[
+                        field
+                    ] = f"{link.step_id}.{link.value_name}"
+            steps.append(src)
+
+        return {
+            "pipeline_name": self.pipeline_name,
+            "doc": self.doc.full_doc,
+            "steps": steps,
+            "input_aliases": self.input_aliases,
+            "output_aliases": self.output_aliases,
+        }
+
     def create_renderable(self, **config: Any) -> RenderableType:
 
         table = Table(show_header=False, box=box.SIMPLE)
