@@ -5,10 +5,11 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
-import structlog
 import uuid
 from typing import Dict, Mapping, Union
 
+import structlog
+
 from kiara.models.events.pipeline import PipelineEvent, PipelineState
 from kiara.models.module.pipeline.pipeline import Pipeline, PipelineListener
 from kiara.registries.jobs import JobRegistry
@@ -100,7 +101,6 @@ class SinglePipelineController(PipelineController):
                 continue
             combined_outputs[step_id] = record.outputs
             for output_id in record.outputs.values():
-                assert output_id not in result.keys()
                 result[output_id] = job_id
 
         self.pipeline.set_multiple_step_outputs(
@@ -175,7 +175,7 @@ class SinglePipelineBatchController(SinglePipelineController):
     def auto_process(self, auto_process: bool):
         self._auto_process = auto_process
 
-    def process_pipeline(self):
+    def process_pipeline(self) -> Mapping[str, Union[uuid.UUID, Exception]]:
 
         log = logger.bind(pipeline_id=self.pipeline.pipeline_id)
         if self._is_running:
@@ -187,6 +187,7 @@ class SinglePipelineBatchController(SinglePipelineController):
 
         log.debug("execute.pipeline")
         self._is_running = True
+        all_job_ids: Dict[str, Union[Exception, uuid.UUID]] = {}
         try:
             for idx, stage in enumerate(
                 self.pipeline.structure.processing_stages, start=1
@@ -209,6 +210,7 @@ class SinglePipelineBatchController(SinglePipelineController):
                         job_id = self.process_step(step_id)
                         job_ids[step_id] = job_id
                     except Exception as e:
+                        all_job_ids[step_id] = e
                         # TODO: cancel running jobs?
                         log_exception(e)
                         log.error(
@@ -216,15 +218,16 @@ class SinglePipelineBatchController(SinglePipelineController):
                             step_id=step_id,
                             error=e,
                         )
-                        return False
 
                 self.set_processing_results(job_ids=job_ids)
                 log.debug(
                     "execute_finished.pipeline.stage",
                     stage=idx,
                 )
+                all_job_ids.update(job_ids)
 
         finally:
             self._is_running = False
 
         log.debug("execute_finished.pipeline")
+        return all_job_ids
