@@ -5,13 +5,15 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
-import networkx as nx
 from functools import lru_cache
+from typing import Any, Dict, Iterable, List, Mapping, Set, Union
+
+import networkx as nx
 from pydantic import Field, PrivateAttr, root_validator
 from rich.console import RenderableType
 from rich.tree import Tree
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Set, Union
 
+from kiara.exceptions import InvalidPipelineConfig
 from kiara.models import KiaraModel
 from kiara.models.module.pipeline import PipelineConfig, PipelineStep
 from kiara.models.module.pipeline.value_refs import (
@@ -24,9 +26,6 @@ from kiara.models.module.pipeline.value_refs import (
 )
 from kiara.models.values.value_schema import ValueSchema
 
-if TYPE_CHECKING:
-    pass
-
 
 def generate_pipeline_endpoint_name(step_id: str, value_name: str):
 
@@ -157,13 +156,17 @@ class PipelineStructure(KiaraModel):
 
         invalid_input_aliases = [a for a in _input_aliases.values() if "." in a]
         if invalid_input_aliases:
-            raise Exception(
-                f"Invalid input aliases, aliases can't contain special characters: {', '.join(invalid_input_aliases)}."
+            raise InvalidPipelineConfig(
+                f"Invalid input aliases, aliases can't contain special characters: {', '.join(invalid_input_aliases)}.",
+                config=values.get("pipeline_config", None),
+                details=f"Invalid characters: {', '.join(invalid_input_aliases)}.",
             )
         invalid_output_aliases = [a for a in _input_aliases.values() if "." in a]
         if invalid_input_aliases:
-            raise Exception(
-                f"Invalid input aliases, aliases can't contain special characters: {', '.join(invalid_output_aliases)}."
+            raise InvalidPipelineConfig(
+                f"Invalid input aliases, aliases can't contain special characters: {', '.join(invalid_output_aliases)}.",
+                config=values.get("pipeline_config"),
+                details=f"Invalid characters: {', '.join(invalid_output_aliases)}.",
             )
 
         valid_input_names = set()
@@ -174,9 +177,18 @@ class PipelineStructure(KiaraModel):
             a for a in _input_aliases.keys() if a not in valid_input_names
         ]
         if invalid_input_aliases:
-            raise Exception(
-                f"Invalid input reference(s): {', '.join(invalid_input_aliases)}. Must be one of: {', '.join(valid_input_names)}"
+            msg = "Invalid input reference(s)."
+            details = "Invalid reference(s):\n"
+            for iia in invalid_input_aliases:
+                details += f" - {iia}\n"
+            details += "\nMust be one of: \n"
+            for name in valid_input_names:
+                details += f"  - {name}\n"
+
+            raise InvalidPipelineConfig(
+                msg, config=values.get("pipeline_config", {}), details=details
             )
+
         valid_output_names = set()
         for step in _steps:
             for output_name in step.module.output_names:
@@ -185,9 +197,16 @@ class PipelineStructure(KiaraModel):
             a for a in _output_aliases.keys() if a not in valid_output_names
         ]
         if invalid_output_names:
-            raise Exception(
-                f"Invalid output reference(s): {', '.join(invalid_output_names)}. Must be one of: {', '.join(valid_output_names)}"
-            )
+
+            msg = "Invalid output reference(s)."
+            details = "Invalid reference(s):\n"
+            for iia in invalid_output_names:
+                details += f" - {iia}\n"
+            details += "\nMust be one of: \n"
+            for name in valid_output_names:
+                details += f"  - {name}\n"
+
+            raise InvalidPipelineConfig(msg, values.get("pipeline_config", {}), details)
 
         # stages = PipelineStage.from_pipeline_structure(stages=)
 
@@ -369,6 +388,29 @@ class PipelineStructure(KiaraModel):
             for output_name, w_out in self.pipeline_output_refs.items()
         }
 
+    def get_pipeline_inputs_schema_for_step(
+        self, step_id: str
+    ) -> Mapping[str, ValueSchema]:
+
+        result = {}
+        for field, ref in self.pipeline_input_refs.items():
+            for con in ref.connected_inputs:
+                if con.step_id == step_id:
+                    result[field] = ref.value_schema
+                    break
+        return result
+
+    def get_pipeline_outputs_schema_for_step(
+        self, step_id: str
+    ) -> Mapping[str, ValueSchema]:
+
+        result = {}
+        for field, ref in self.pipeline_output_refs.items():
+            if ref.connected_output.step_id == step_id:
+                result[field] = ref.value_schema
+
+        return result
+
     def get_processing_stage(self, step_id: str) -> int:
         """Return the processing stage for the specified step_id.
 
