@@ -7,12 +7,8 @@
 
 import abc
 import inspect
-import structlog
 import uuid
 from abc import abstractmethod
-from multiformats import CID
-from pydantic import BaseModel, Field, ValidationError
-from rich.console import RenderableType
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -25,7 +21,17 @@ from typing import (
     Union,
 )
 
-from kiara.exceptions import KiaraModuleConfigException
+import structlog
+from multiformats import CID
+from pydantic import BaseModel, Field, ValidationError
+from rich.console import RenderableType
+
+from kiara.exceptions import (
+    InvalidValuesException,
+    KiaraException,
+    KiaraModuleConfigException,
+    KiaraProcessingException,
+)
 from kiara.models.module import KiaraModuleConfig
 from kiara.models.module.jobs import JobLog
 from kiara.models.values.value_schema import ValueSchema
@@ -39,6 +45,7 @@ from kiara.utils.values import (
 from kiara.utils.yaml import StringYAML
 
 if TYPE_CHECKING:
+    from kiara.context import Kiara
     from kiara.models.module.manifest import Manifest
     from kiara.models.values.value import ValueMap
     from kiara.operations import Operation
@@ -196,7 +203,7 @@ class InputOutputObject(abc.ABC):
             )
 
         except Exception as e:
-            raise Exception(f"Can't create input schemas for instance '{self.alias}': {e}")  # type: ignore
+            raise KiaraException(f"Can't create input schemas for instance of '{self.alias}'.", parent=e)  # type: ignore
 
     @property
     def outputs_schema(self) -> Mapping[str, ValueSchema]:
@@ -231,7 +238,10 @@ class InputOutputObject(abc.ABC):
                 import traceback
 
                 traceback.print_exc()
-            raise Exception(f"Can't create output schemas for instance of module '{self.alias}': {e}")  # type: ignore
+            raise KiaraException(
+                f"Can't create output schemas for instance of module '{self.alias}': {e}",
+                parent=e,
+            )
 
     @property
     def input_names(self) -> Iterable[str]:
@@ -245,10 +255,12 @@ class InputOutputObject(abc.ABC):
 
     def augment_module_inputs(self, inputs: Mapping[str, Any]) -> Dict[str, Any]:
 
-        return augment_values(
+        augmented = augment_values(
             values=inputs, schemas=self.inputs_schema, constants=self.constants
         )
 
+        return augmented
+
     # def augment_outputs(self, outputs: Mapping[str, Any]) -> Dict[str, Any]:
     #     return augment_values(values=outputs, schemas=self.outputs_schema)
 
@@ -438,6 +450,56 @@ class KiaraModule(InputOutputObject, Generic[KIARA_CONFIG]):
                 f"Error accessing config value '{key}' in module {self.__class__._module_type_name}."  # type: ignore
             )
 
+    def run(self, kiara: "Kiara", **inputs: Any) -> "ValueMap":
+        """Run the module ad-hoc.
+
+        This is mostly used in unit tests, you typically want to run a module via the KiaraAPI instance.
+
+        Arguments:
+            kiara: the kiara context
+            inputs: the inputs for this module
+
+        Returns:
+            the outputs of this module run as a ValueMap instance
+        """
+
+        from kiara.models.values.value import ValueMap, ValueMapWritable, ValuePedigree
+
+        _inputs: ValueMap = kiara.data_registry.create_valuemap(
+            data=inputs, schema=self.inputs_schema
+        )
+
+        if _inputs.check_invalid():
+            raise InvalidValuesException(
+                msg=f"Invalid inputs for module '{self.module_type_name}'.",
+                invalid_values=_inputs.check_invalid(),
+            )
+        environments = {
+            env_name: env.instance_id
+            for env_name, env in kiara.current_environments.items()
+        }
+
+        result_pedigree = ValuePedigree(
+            kiara_id=kiara.id,
+            module_type=self.module_type_name,
+            module_config=self.config.dict(),
+            inputs={k: v.value_id for k, v in _inputs.items()},
+            environments=environments,
+        )
+
+        unique_result_values = self.characteristics.unique_result_values
+
+        outputs = ValueMapWritable.create_from_schema(
+            kiara=kiara,
+            schema=self.outputs_schema,
+            pedigree=result_pedigree,
+            unique_value_ids=unique_result_values,
+        )
+        job_log = JobLog()
+        self.process_step(inputs=_inputs, outputs=outputs, job_log=job_log)
+
+        return outputs
+
     def process_step(
         self, inputs: "ValueMap", outputs: "ValueMap", job_log: JobLog
     ) -> None:
@@ -463,9 +525,12 @@ class KiaraModule(InputOutputObject, Generic[KIARA_CONFIG]):
 
         try:
             self.process(**process_inputs)  # type: ignore
+        except KiaraProcessingException as kpe:
+            log_exception(kpe)
+            raise kpe
         except Exception as e:
             log_exception(e)
-            raise e
+            raise KiaraProcessingException(e, module=self, inputs=inputs)
 
     def __eq__(self, other):
         if self.__class__ != other.__class__:
