@@ -5,10 +5,12 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 import inspect
-from pydantic import Field
 from typing import Any, Dict, Iterable, Mapping, Union
 
+from pydantic import Field
+
 from kiara.models.module import KiaraModuleConfig
+from kiara.models.module.jobs import JobLog
 from kiara.models.values.value import Value, ValueMap, ValueMapReadOnly
 from kiara.models.values.value_schema import ValueSchema
 from kiara.modules import KiaraModule
@@ -70,7 +72,10 @@ class CreateFromModule(KiaraModule):
         )
 
         schema = {
-            source_type: {"type": source_type, "doc": "The type of the source value."},
+            source_type: {
+                "type": source_type,
+                "doc": f"The source value (of type '{source_type}').",
+            },
         }
         if optional:
             for field, field_schema in optional.items():
@@ -100,11 +105,11 @@ class CreateFromModule(KiaraModule):
         return {
             self.get_config_value("target_type"): {
                 "type": self.get_config_value("target_type"),
-                "doc": "The result value.",
+                "doc": f"The result value (of type '{self.get_config_value('target_type')}').",
             }
         }
 
-    def process(self, inputs: ValueMap, outputs: ValueMap) -> None:
+    def process(self, inputs: ValueMap, outputs: ValueMap, job_log: JobLog) -> None:
 
         source_type = self.get_config_value("source_type")
         target_type = self.get_config_value("target_type")
@@ -115,6 +120,8 @@ class CreateFromModule(KiaraModule):
         source_value = inputs.get_value_obj(source_type)
 
         signature = inspect.signature(func)
+        args: Dict[str, Any] = {"source_value": source_value}
+
         if "optional" in signature.parameters:
             optional: Dict[str, Value] = {}
             op_schemas = {}
@@ -123,12 +130,12 @@ class CreateFromModule(KiaraModule):
                     continue
                 optional[field] = inputs.get_value_obj(field)
                 op_schemas[field] = schema
-            result = func(
-                source_value=source_value,
-                optional=ValueMapReadOnly(
-                    value_items=optional, values_schema=op_schemas
-                ),
+            args["optional"] = ValueMapReadOnly(
+                value_items=optional, values_schema=op_schemas
             )
-        else:
-            result = func(source_value=source_value)
+
+        if "job_log" in signature.parameters:
+            args["job_log"] = job_log
+
+        result = func(**args)
         outputs.set_value(target_type, result)
