@@ -5,9 +5,10 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
-from pydantic import Field, validator
 from typing import Any, Iterable, Mapping, Tuple, Union
 
+from pydantic import Field, validator
+
 from kiara.models.module import KiaraModuleConfig
 from kiara.models.values.value import ValueMap
 from kiara.models.values.value_schema import ValueSchema
@@ -51,7 +52,7 @@ class PrettyPrintModule(KiaraModule):
             attr = attr[14:]
             end_start_type = attr.find("__as__")
             source_type = attr[0:end_start_type]
-            target_type = attr[end_start_type + 6 :]  # noqa
+            target_type = attr[end_start_type + 6 :]
             result.append((source_type, target_type))
         return result
 
