@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 
+from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Union
+
 import structlog
 from pydantic import Field
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Union
 
 from kiara.models.documentation import DocumentationMetadataModel
 from kiara.models.module.manifest import Manifest
@@ -399,7 +400,7 @@ class FilterOperationType(OperationType[FilterOperationDetails]):
         manifest = Manifest(
             module_type="pipeline", module_config=pipeline_config.dict()
         )
-        module = self._kiara.create_module(manifest=manifest)
+        module = self._kiara.module_registry.create_module(manifest=manifest)
 
         op_details = PipelineOperationDetails.create_operation_details(
             operation_id=module.config.pipeline_name,
