@@ -5,7 +5,6 @@
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
 import abc
-import structlog
 import uuid
 from typing import (
     TYPE_CHECKING,
@@ -18,6 +17,8 @@ from typing import (
     Union,
 )
 
+import structlog
+
 from kiara.models.events.alias_registry import AliasArchiveAddedEvent
 from kiara.registries import BaseArchive
 from kiara.registries.data import ValueLink
@@ -161,7 +162,7 @@ class AliasRegistry(object):
     @property
     def aliases_by_id(self) -> Mapping[uuid.UUID, Set[AliasItem]]:
         if self._cached_aliases_by_id is None:
-            self.aliases  # noqa
+            self.aliases
         return self._cached_aliases_by_id  # type: ignore
 
     @property
@@ -253,7 +254,7 @@ class AliasRegistry(object):
 
         value_id = self._get_value_id(value_id=value_id)
 
-        aliases = set([a.full_alias for a in self.aliases_by_id.get(value_id, [])])
+        aliases = {a.full_alias for a in self.aliases_by_id.get(value_id, [])}
 
         if search_dynamic_archives:
             for archive_alias, archive in self._alias_archives.items():
@@ -266,13 +267,26 @@ class AliasRegistry(object):
         return aliases
 
     def register_aliases(
-        self, value_id: Union[uuid.UUID, ValueLink, str], *aliases: str
+        self,
+        value_id: Union[uuid.UUID, ValueLink, str],
+        *aliases: str,
+        allow_overwrite: bool = False,
     ):
 
         value_id = self._get_value_id(value_id=value_id)
         store_name = self.default_alias_store
         store: AliasStore = self.get_archive(archive_id=store_name)  # type: ignore
         self.aliases  # noqu
+
+        if not allow_overwrite:
+            duplicates = []
+            for alias in aliases:
+                if alias in self.aliases.keys():
+                    duplicates.append(alias)
+
+            if duplicates:
+                raise Exception(f"Duplicate aliases: {duplicates}")
+
         store.register_aliases(value_id, *aliases)
 
         for alias in aliases:
