@@ -6,9 +6,7 @@
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 import abc
 import copy
-import structlog
 import uuid
-from rich.console import RenderableType
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -22,6 +20,9 @@ from typing import (
     Union,
 )
 
+import structlog
+from rich.console import RenderableType
+
 from kiara.data_types import DataType
 from kiara.data_types.included_core_types import NoneType
 from kiara.defaults import (
@@ -540,7 +541,7 @@ class DataRegistry(object):
             if stored:
                 self._values_by_hash[value_hash] = stored
 
-        return set((self.get_value(value=v_id) for v_id in stored))
+        return {self.get_value(value=v_id) for v_id in stored}
 
     def find_destinies_for_value(
         self, value_id: uuid.UUID, alias_filter: Union[str, None] = None
@@ -889,7 +890,7 @@ class DataRegistry(object):
                 f"No deserialize operation found for data type: {value.data_type_name}"
             )
 
-        module = self._kiara.create_module(manifest=manifest)
+        module = self._kiara.module_registry.create_module(manifest=manifest)
         op = Operation.create_from_module(module=module)
 
         input_field_match: Union[str, None] = None
@@ -944,17 +945,34 @@ class DataRegistry(object):
 
         return parsed
 
-    def load_values(self, values: Mapping[str, Union[uuid.UUID, None]]) -> ValueMap:
+    def load_values(
+        self,
+        values: Mapping[str, Union[uuid.UUID, None, str, ValueLink]],
+        values_schema: Union[None, Mapping[str, ValueSchema]] = None,
+    ) -> ValueMap:
 
         value_items = {}
-        schemas = {}
-        for field_name, value_id in values.items():
-            if value_id is None:
-                value_id = NONE_VALUE_ID
+        if values_schema:
 
-            value = self.get_value(value=value_id)
-            value_items[field_name] = value
-            schemas[field_name] = value.value_schema
+            schemas = values_schema
+            for k in schemas.keys():
+                if k not in values.keys():
+                    value_items[k] = self.get_value(NOT_SET_VALUE_ID)
+                else:
+                    value_id = values[k]
+                    if value_id is None:
+                        value_id = NONE_VALUE_ID
+
+                    value_items[k] = self.get_value(value_id)
+        else:
+            schemas = {}
+            for field_name, value_id in values.items():
+                if value_id is None:
+                    value_id = NONE_VALUE_ID
+
+                value = self.get_value(value=value_id)
+                value_items[field_name] = value
+                schemas[field_name] = value.value_schema
 
         return ValueMapReadOnly(value_items=value_items, values_schema=schemas)
 
@@ -1028,6 +1046,7 @@ class DataRegistry(object):
                     data=value_data, schema=value_schema, reuse_existing=True
                 )
                 values[input_name] = value
+
             except Exception as e:
 
                 log_exception(e)
