@@ -6,11 +6,12 @@
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
 import abc
-import structlog
 import uuid
-from bidict import bidict
 from typing import TYPE_CHECKING, Any, Dict, Iterable, Mapping, Type, Union
 
+import structlog
+from bidict import bidict
+
 from kiara.context.config import JobCacheStrategy
 from kiara.exceptions import FailedJobException
 from kiara.models.events import KiaraEvent
@@ -428,7 +429,7 @@ class JobRegistry(object):
         self, manifest: Manifest, inputs: Mapping[str, Any]
     ) -> JobConfig:
 
-        module = self._kiara.create_module(manifest=manifest)
+        module = self._kiara.module_registry.create_module(manifest=manifest)
 
         job_config = JobConfig.create_from_module(
             data_registry=self._kiara.data_registry, module=module, inputs=inputs
@@ -514,7 +515,7 @@ class JobRegistry(object):
                     msg = str(job._exception)
                     if not msg:
                         msg = repr(job._exception)
-                raise FailedJobException(job=job, msg=msg)
+                raise FailedJobException(job=job, msg=msg, parent=job._exception)
             else:
                 raise Exception(f"Can't retrieve job with id '{job_id}': no such job.")
 
@@ -546,7 +547,7 @@ class JobRegistry(object):
             return results
         elif job_id in self._failed_jobs.values():
             j = self._processor.get_job(job_id=job_id)
-            raise FailedJobException(job=j)
+            raise FailedJobException(job=j, parent=j._exception)
         else:
             raise Exception(f"Could not find job with id: {job_id}")
 
