@@ -5,8 +5,10 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
-import structlog
+import json
+import os.path
 import sys
+from pathlib import Path
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -20,7 +22,10 @@ from typing import (
     Union,
 )
 
-from kiara.exceptions import NoSuchOperationException
+import structlog
+from ruamel.yaml import YAML
+
+from kiara.exceptions import InvalidOperationException, NoSuchOperationException
 from kiara.interfaces.python_api.models.info import (
     OperationTypeClassesInfo,
     OperationTypeInfo,
@@ -32,14 +37,17 @@ from kiara.models.module.operation import (
     OperationConfig,
     PipelineOperationConfig,
 )
+from kiara.models.module.pipeline import PipelineConfig
 from kiara.models.python_class import KiaraModuleInstance
 from kiara.operations import OperationType
-from kiara.utils import log_exception
+from kiara.utils import log_exception, log_message
+from kiara.utils.pipelines import find_pipeline_data_in_paths
 
 if TYPE_CHECKING:
     from kiara.context import Kiara
 
 logger = structlog.getLogger()
+yaml = YAML(typ="safe")
 
 
 OP_TYPE = TypeVar("OP_TYPE", bound=OperationType)
@@ -66,10 +74,12 @@ class OperationRegistry(object):
         self._operation_types: Union[Dict[str, OperationType], None] = None
 
         self._operations: Union[Dict[str, Operation], None] = None
-        self._operations_by_type: Union[Dict[str, Iterable[str]], None] = None
+        self._operations_by_type: Union[Dict[str, List[str]], None] = None
 
         self._module_map: Union[Dict[str, Dict[str, Any]], None] = None
 
+        self._invalid_operations: Dict[str, Any] = {}
+
     @property
     def is_initialized(self) -> bool:
 
@@ -217,6 +227,23 @@ class OperationRegistry(object):
                     ).append(op_config)
                     continue
 
+            except Exception as e:
+                details: Dict[str, Any] = {}
+                module_id = op_config.retrieve_module_type(kiara=self._kiara)
+                details["module_id"] = module_id
+                if module_id == "pipeline":
+                    details["pipeline_name"] = op_config.pipeline_name  # type: ignore
+                msg: Union[str, Exception] = str(e)
+                if not msg:
+                    msg = e
+                details["details"] = msg
+                logger.error("invalid.operation", **details)
+                self._invalid_operations[op_config.pipeline_name] = details  # type: ignore
+                log_exception(e)
+                continue
+
+            try:
+
                 module_type = op_config.retrieve_module_type(kiara=self._kiara)
                 if module_type not in self._kiara.module_type_names:
                     deferred_module_names.setdefault(module_type, []).append(op_config)
@@ -245,12 +272,12 @@ class OperationRegistry(object):
                             _op.operation_id
                         )
             except Exception as e:
-                details: Dict[str, Any] = {}
+                details = {}
                 module_id = op_config.retrieve_module_type(kiara=self._kiara)
                 details["module_id"] = module_id
                 if module_id == "pipeline":
                     details["pipeline_name"] = op_config.pipeline_name  # type: ignore
-                msg: Union[str, Exception] = str(e)
+                msg = str(e)
                 if not msg:
                     msg = e
                 details["details"] = msg
@@ -349,15 +376,23 @@ class OperationRegistry(object):
                         details = {}
                         module_id = op_config.retrieve_module_type(kiara=self._kiara)
                         details["module_id"] = module_id
+                        try:
+                            details["module_config"] = op_config.retrieve_module_config(
+                                kiara=self._kiara
+                            )
+                        except Exception as xe:
+                            details["module_config"] = str(xe)
                         if module_id == "pipeline":
                             details["pipeline_name"] = op_config.pipeline_name  # type: ignore
+
                         msg = str(e)
                         if not msg:
                             msg = e
                         details["details"] = msg
                         error_details[missing_op_id] = details
                         exc_info = sys.exc_info()
-                        details["exception"] = exc_info[1]
+                        details["parent"] = exc_info[1]
+
                         continue
 
             for name, dependencies in deferred_module_names.items():
@@ -372,11 +407,12 @@ class OperationRegistry(object):
                     if mn in operations.keys():
                         continue
                     details = error_details.get(missing_op_id, {"details": "-- n/a --"})
-                    exception = details.pop("exception", None)
+                    exception = details.get("parent", None)
                     if exception:
                         log_exception(exception)
 
-                    logger.error(f"invalid.operation.{mn}", operation_id=mn, **details)
+                    self._invalid_operations[mn] = details
+                    log_message(f"invalid.operation.{mn}", operation_id=mn, **details)
                 break
 
         self._operations = {}
@@ -391,6 +427,127 @@ class OperationRegistry(object):
 
         return self._operations
 
+    def register_pipelines(self, *paths: Union[str, Path]) -> Dict[str, Operation]:
+        """Register pipelines from one or more paths.
+
+        Args:
+            *paths: one or more paths to load pipelines from.
+        """
+
+        pipeline_data = find_pipeline_data_in_paths(
+            {k if isinstance(k, str) else k.as_posix(): {} for k in paths}
+        )
+        duplicates = set()
+        for op_id in pipeline_data.keys():
+            if op_id in self.operations.keys():
+                duplicates.add(op_id)
+
+        if duplicates:
+            raise Exception(
+                "Can't register pipelines from the provided path(s), duplicate operation ids found: "
+                + ", ".join(sorted(duplicates))
+            )
+
+        ops = {}
+        for op_id, op_data in pipeline_data.items():
+            # TODO: what to do with the additional data, like source and source type?
+            op = self.register_pipeline(data=op_data["data"], operation_id=op_id)
+            ops[op.operation_id] = op
+        return ops
+
+    def register_pipeline(
+        self,
+        data: Union[Path, str, Mapping[str, Any]],
+        operation_id: Union[str, None] = None,
+    ) -> Operation:
+
+        if isinstance(data, Path):
+            if not data.is_file():
+                raise Exception(
+                    f"Can't register operation from path '{data.as_posix()}: path is not a file."
+                )
+
+            pipeline_config = PipelineConfig.from_file(
+                data.as_posix(), kiara=self._kiara, pipeline_name=operation_id
+            )
+        elif isinstance(data, Mapping):
+
+            pipeline_config = PipelineConfig.from_config(
+                pipeline_name=operation_id, data=data, kiara=self._kiara
+            )
+        elif isinstance(data, str):
+            if os.path.isfile((os.path.realpath(data))):
+                pipeline_config = PipelineConfig.from_file(
+                    data, kiara=self._kiara, pipeline_name=operation_id
+                )
+            else:
+                config_data = None
+                try:
+                    config_data = json.loads(data)
+                except Exception:
+                    try:
+                        config_data = yaml.load(data)
+                    except Exception:
+                        pass
+                if config_data:
+                    pipeline_config = PipelineConfig.from_config(
+                        pipeline_name=operation_id, data=config_data, kiara=self._kiara
+                    )
+                else:
+                    raise Exception(
+                        f"Can't register pipeline with id '{operation_id}': can't parse data as file path, json or yaml."
+                    )
+        else:
+            raise Exception(
+                f"Can't register pipeline with id '{operation_id}': invalid type '{type(data)}' for pipeline data: {type(data)}"
+            )
+
+        _operation_id = pipeline_config.pipeline_name
+        if operation_id:
+            assert _operation_id == operation_id
+
+        if _operation_id in self.operation_ids:
+            raise Exception(
+                f"Can't register pipeline with id '{_operation_id}': operation id already in use."
+            )
+
+        manifest = Manifest.construct(
+            module_type="pipeline", module_config=pipeline_config.dict()
+        )
+        module = self._kiara.module_registry.create_module(manifest)
+
+        from kiara.operations.included_core_operations.pipeline import (
+            PipelineOperationDetails,
+        )
+
+        op_details = PipelineOperationDetails.create_operation_details(
+            operation_id=module.config.pipeline_name,
+            pipeline_inputs_schema=module.inputs_schema,
+            pipeline_outputs_schema=module.outputs_schema,
+            pipeline_config=module.config,
+        )
+
+        metadata: Dict[str, Any] = {}
+        operation = Operation(
+            module_type=manifest.module_type,
+            module_config=manifest.module_config,
+            operation_id=_operation_id,
+            operation_details=op_details,
+            module_details=KiaraModuleInstance.from_module(module),
+            metadata=metadata,
+            doc=pipeline_config.doc,
+        )
+        operation._module = module
+        assert self._operations is not None
+        self._operations[_operation_id] = operation
+        current_pipelines = self.operations_by_type.get("pipeline", [])
+        current_pipelines.append(_operation_id)  # type: ignore
+        assert self._operations_by_type is not None
+        self._operations_by_type["pipeline"] = sorted(current_pipelines)
+
+        logger.debug("pipeline.registered", operation_id=_operation_id)
+        return operation
+
     def _create_operations(
         self,
         manifest: Manifest,
@@ -398,7 +555,7 @@ class OperationRegistry(object):
         metadata: Union[Mapping[str, Any], None] = None,
     ) -> Dict[str, Operation]:
 
-        module = self._kiara.create_module(manifest)
+        module = self._kiara.module_registry.create_module(manifest)
         op_types = {}
 
         if metadata is None:
@@ -428,10 +585,13 @@ class OperationRegistry(object):
     def get_operation(self, operation_id: str) -> Operation:
 
         if operation_id not in self.operation_ids:
-            raise NoSuchOperationException(
-                operation_id=operation_id,
-                available_operations=sorted(self.operation_ids),
-            )
+            if operation_id in self._invalid_operations.keys():
+                raise InvalidOperationException(self._invalid_operations[operation_id])
+            else:
+                raise NoSuchOperationException(
+                    operation_id=operation_id,
+                    available_operations=sorted(self.operation_ids),
+                )
 
         op = self.operations[operation_id]
         return op
@@ -449,5 +609,13 @@ class OperationRegistry(object):
     def operations_by_type(self) -> Mapping[str, Iterable[str]]:
 
         if self._operations_by_type is None:
-            self.operations  # noqa
+            self.operations
         return self._operations_by_type  # type: ignore
+
+    def find_operation_id(self, manifest: Manifest) -> Union[str, None]:
+
+        for op in self.operations.values():
+            if manifest.manifest_cid == op.manifest_cid:
+                return op.operation_id
+
+        return None
