@@ -5,9 +5,10 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
-from bidict import bidict
 from typing import TYPE_CHECKING, Any, Dict, List, Mapping, Set, Type, Union
 
+from bidict import bidict
+
 from kiara.data_types import DataType
 from kiara.defaults import KIARA_ROOT_TYPE_NAME
 from kiara.exceptions import DataTypeUnknownException
@@ -98,7 +99,7 @@ class TypeRegistry(object):
     def data_type_profiles(self) -> Mapping[str, Mapping[str, Any]]:
 
         if self._type_profiles is None:
-            self.data_type_classes  # noqa
+            self.data_type_classes
         assert self._type_profiles is not None
         return self._type_profiles
 
