@@ -10,8 +10,6 @@ import inspect
 import os
 import sys
 from pkgutil import iter_modules
-from rich.markdown import Markdown
-from stevedore import ExtensionManager
 from types import ModuleType
 from typing import (
     TYPE_CHECKING,
@@ -27,6 +25,9 @@ from typing import (
     Union,
 )
 
+from rich.markdown import Markdown
+from stevedore import ExtensionManager
+
 from kiara.utils import (
     _get_all_subclasses,
     camel_case_to_snake_case,
@@ -38,13 +39,15 @@ from kiara.utils import (
 from kiara.utils.develop import log_dev_message
 
 if TYPE_CHECKING:
+    from kiara.data_types import DataType
+    from kiara.models import KiaraModel
     from kiara.modules import KiaraModule
     from kiara.operations import OperationType
-    from kiara.data_types import DataType
     from kiara.registries import KiaraArchive
-    from kiara.models import KiaraModel
+    from kiara.renderers import KiaraRenderer
 
 import logging
+
 import structlog
 
 logger = structlog.getLogger()
@@ -96,8 +99,8 @@ def find_subclasses_under(
         a list of all subclasses
     """
 
-    if hasattr(sys, "frozen"):
-        raise NotImplementedError("Pyinstaller bundling not supported yet.")
+    # if hasattr(sys, "frozen"):
+    #     raise NotImplementedError("Pyinstaller bundling not supported yet.")
 
     try:
         if isinstance(python_module, str):
@@ -544,8 +547,8 @@ def find_pipeline_base_path_for_module(
     module: Union[str, ModuleType]
 ) -> Union[str, None]:
 
-    if hasattr(sys, "frozen"):
-        raise NotImplementedError("Pyinstaller bundling not supported yet.")
+    # if hasattr(sys, "frozen"):
+    #     raise NotImplementedError("Pyinstaller bundling not supported yet.")
 
     if isinstance(module, str):
         module = importlib.import_module(module)
@@ -676,6 +679,37 @@ def find_all_cli_subcommands():
     return [plugin.plugin for plugin in mgr]
 
 
+def find_all_kiara_renderers() -> Dict[str, Type["KiaraRenderer"]]:
+    """Find all [KiaraComponent][kiara_plugin.streamilt.components.KiaraComponent] subclasses via package entry points.
+
+    TODO
+    """
+
+    from kiara.renderers import KiaraRenderer
+
+    components = load_all_subclasses_for_entry_point(
+        entry_point_name="kiara.renderers",
+        base_class=KiaraRenderer,  # type: ignore
+        type_id_key="_renderer_name",
+        type_id_func=_cls_name_id_func,
+        attach_python_metadata=True,
+    )
+
+    return components
+
+
+def find_kiara_renderers_under(
+    module: Union[str, ModuleType],
+) -> List[Type["KiaraRenderer"]]:
+
+    from kiara.renderers import KiaraRenderer
+
+    return find_subclasses_under(
+        base_class=KiaraRenderer,  # type: ignore
+        python_module=module,
+    )
+
+
 # def _find_pipeline_folders_using_callable(
 #     func: Union[Callable, Tuple]
 # ) -> Tuple[Optional[str], str]:
