@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 import copy
-import dpath.util
 from typing import Any, Dict, Mapping
 
+import dpath
+
 
 def merge_dicts(*dicts: Mapping[str, Any]) -> Dict[str, Any]:
 
@@ -11,6 +12,6 @@ def merge_dicts(*dicts: Mapping[str, Any]) -> Dict[str, Any]:
 
     current: Dict[str, Any] = {}
     for d in dicts:
-        dpath.util.merge(current, copy.deepcopy(d))
+        dpath.merge(current, dict(copy.deepcopy(d)))
 
     return current
