@@ -74,8 +74,8 @@ def shard(digest, depth, width):
     # This creates a list of `depth` number of tokens with width
     # `width` from the first part of the id plus the remainder.
     return compact(
-        [digest[i * width : width * (i + 1)] for i in range(depth)]  # noqa
-        + [digest[depth * width :]]  # noqa
+        [digest[i * width : width * (i + 1)] for i in range(depth)]
+        + [digest[depth * width :]]
     )
 
 
@@ -471,7 +471,7 @@ class Stream(object):
         except Exception:
             buffer_size = 8192
 
-        self._obj = obj
+        self._obj: BinaryIO = obj  # type: ignore
         self._pos = pos
         self._buffer_size = buffer_size
 
