@@ -4,18 +4,19 @@
 #  Copyright (c) 2021, Markus Binsteiner
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
-import dag_cbor
 import hashlib
-from dag_cbor.encoding import EncodableType
+from typing import Tuple, Union
+
+import dag_cbor
+from dag_cbor import Kind
 from multiformats import CID, multihash
 from multiformats.multicodec import Multicodec
 from multiformats.multihash import Multihash
 from multiformats.varint import BytesLike
-from typing import Tuple, Union
 
 
 def compute_cid(
-    data: EncodableType,
+    data: Kind,
     hash_codec: str = "sha2-256",
     encode: str = "base58btc",
 ) -> Tuple[bytes, CID]:
