@@ -5,18 +5,30 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 import os
-from ruamel.yaml import YAML
-from typing import TYPE_CHECKING, Any, Dict, Mapping, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Mapping, Union
 
-from kiara.exceptions import NoSuchExecutionTargetException, NoSuchOperationException
+from rich.console import Group, RenderableType
+from rich.markdown import Markdown
+from ruamel.yaml import YAML
+
+from kiara.exceptions import (
+    InvalidValuesException,
+    NoSuchExecutionTargetException,
+    NoSuchOperationException,
+)
 from kiara.interfaces.python_api.models.info import OperationGroupInfo, OperationInfo
 from kiara.models.module.jobs import ExecutionContext
 from kiara.models.module.manifest import Manifest
 from kiara.models.module.operation import Operation
 from kiara.models.module.pipeline import PipelineConfig
 from kiara.utils.files import get_data_from_file
+from kiara.utils.output import (
+    create_table_from_field_schemas,
+    create_value_map_status_renderable,
+)
 
 if TYPE_CHECKING:
+    from kiara import ValueMap
     from kiara.context import Kiara
 
 yaml = YAML(typ="safe")
@@ -77,6 +89,7 @@ def create_operation(
         kiara = Kiara.instance()
 
     operation = None
+
     if module_or_operation in kiara.operation_registry.operation_ids:
 
         operation = kiara.operation_registry.get_operation(module_or_operation)
@@ -85,7 +98,7 @@ def create_operation(
                 manifest = Manifest(
                     module_type=module_or_operation, module_config=operation_config
                 )
-                module = kiara.create_module(manifest=manifest)
+                module = kiara.module_registry.create_module(manifest=manifest)
                 operation = Operation.create_from_module(module)
             else:
                 raise Exception(
@@ -97,10 +110,12 @@ def create_operation(
         and module_or_operation in kiara.module_type_names
     ):
 
+        if operation_config is None:
+            operation_config = {}
         manifest = Manifest(
             module_type=module_or_operation, module_config=operation_config
         )
-        module = kiara.create_module(manifest=manifest)
+        module = kiara.module_registry.create_module(manifest=manifest)
         operation = Operation.create_from_module(module)
 
     elif os.path.isfile(module_or_operation):
@@ -122,7 +137,7 @@ def create_operation(
         )
 
         manifest = kiara.create_manifest("pipeline", config=pipeline_config.dict())
-        module = kiara.create_module(manifest=manifest)
+        module = kiara.module_registry.create_module(manifest=manifest)
 
         operation = Operation.create_from_module(module, doc=pipeline_config.doc)
 
@@ -140,38 +155,45 @@ def create_operation(
                 except Exception:
                     data = None
 
-        if data is not None:
+            if data and not isinstance(data, Mapping):
+                raise Exception(
+                    f"Could not parse module or operation: {module_or_operation}"
+                )
+
+        if data:
             d = dict(data)
             pipeline_name = d.pop("pipeline_name", None)
             if pipeline_name is not None:
 
-                try:
-                    execution_context = ExecutionContext(
-                        pipeline_dir=os.path.abspath(
-                            os.path.dirname(module_or_operation)
-                        )
-                    )
-                    pipeline_config = PipelineConfig.from_config(
-                        pipeline_name=pipeline_name,
-                        data=d,
-                        kiara=kiara,
-                        execution_context=execution_context,
-                    )
+                execution_context = ExecutionContext(
+                    pipeline_dir=os.path.abspath(os.path.dirname(module_or_operation))
+                )
+                pipeline_config = PipelineConfig.from_config(
+                    pipeline_name=pipeline_name,
+                    data=d,
+                    kiara=kiara,
+                    execution_context=execution_context,
+                )
 
-                    manifest = kiara.create_manifest(
-                        "pipeline", config=pipeline_config.dict()
-                    )
-                    module = kiara.create_module(manifest=manifest)
+                manifest = kiara.create_manifest(
+                    "pipeline", config=pipeline_config.dict()
+                )
+                module = kiara.module_registry.create_module(manifest=manifest)
 
-                    operation = Operation.create_from_module(
-                        module, doc=pipeline_config.doc
-                    )
-                except Exception:
-                    pass
+                operation = Operation.create_from_module(
+                    module, doc=pipeline_config.doc
+                )
+            else:
+                raise Exception("Invalid pipeline config, missing 'pipeline_name' key.")
 
         if operation is None:
+
+            if module_or_operation == "pipeline":
+                msg = "Can't assemble pipeline."
+            else:
+                msg = f"Can't assemble operation, invalid operation/module name: {module_or_operation}. Must be registered module or operation name, or file."
             raise NoSuchOperationException(
-                msg=f"Can't assemble operation, invalid operation/module name: {module_or_operation}. Must be registered module or operation name, or file.",
+                msg=msg,
                 operation_id=module_or_operation,
                 available_operations=sorted(kiara.operation_registry.operation_ids),
             )
@@ -186,3 +208,52 @@ def create_operation(
             available_targets=sorted(merged),
         )
     return operation
+
+
+def create_operation_status_renderable(
+    operation: Operation, inputs: Union["ValueMap", None], render_config: Any
+) -> RenderableType:
+
+    show_operation_name = render_config.get("show_operation_name", True)
+    show_operation_doc = render_config.get("show_operation_doc", True)
+    show_inputs = render_config.get("show_inputs", False)
+    show_outputs_schema = render_config.get("show_outputs_schema", False)
+    show_headers = render_config.get("show_headers", True)
+
+    items: List[Any] = []
+
+    if show_operation_name:
+        items.append(f"Operation: [bold]{operation.operation_id}[/bold]")
+    if show_operation_doc and operation.doc.is_set:
+        items.append("")
+        items.append(Markdown(operation.doc.full_doc, style="i"))
+
+    if show_inputs:
+        assert inputs is not None
+        if show_headers:
+            items.append("\nInputs:")
+        _inputs: Union[None, RenderableType] = None
+        try:
+            _inputs = create_value_map_status_renderable(
+                inputs, render_config=render_config
+            )
+        except InvalidValuesException as ive:
+            _inputs = ive.create_renderable(**render_config)
+        except Exception as e:
+            _inputs = f"[red bold]{e}[/red bold]"
+        finally:
+            assert _inputs is not None
+            items.append(_inputs)
+    if show_outputs_schema:
+        if show_headers:
+            items.append("\nOutputs:")
+        outputs_schema = create_table_from_field_schemas(
+            _add_default=False,
+            _add_required=False,
+            _show_header=True,
+            _constants=None,
+            fields=operation.outputs_schema,
+        )
+        items.append(outputs_schema)
+
+    return Group(*items)
