@@ -6,15 +6,8 @@
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
 import json
-import orjson
-import structlog
 from abc import ABC, abstractmethod
 from enum import Enum
-from pydantic import BaseModel, Field, root_validator
-from rich import box
-from rich.console import ConsoleRenderable, Group, RenderableType, RichCast
-from rich.table import Table as RichTable
-from rich.tree import Tree
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -28,7 +21,17 @@ from typing import (
     Union,
 )
 
+import orjson
+import structlog
+from pydantic import BaseModel, Field, root_validator
+from rich import box
+from rich.console import ConsoleRenderable, Group, RenderableType, RichCast
+from rich.markdown import Markdown
+from rich.table import Table as RichTable
+from rich.tree import Tree
+
 from kiara.defaults import SpecialValue
+from kiara.exceptions import KiaraException
 from kiara.models.values.value import ORPHAN, Value, ValueMap
 from kiara.utils.json import orjson_dumps
 
@@ -408,14 +411,16 @@ def create_table_from_base_model_cls(model_cls: Type[BaseModel]):
         row = [field_name]
         p = props.get(field_name, None)
         p_type = None
+        desc = ""
         if p is not None:
             p_type = p.get("type", None)
             # TODO: check 'anyOf' keys
+            desc = p.get("description", "")
 
         if p_type is None:
             p_type = "-- check source --"
         row.append(p_type)
-        desc = p.get("description", "")
+
         row.append(desc)
         row.append("yes" if field.required else "no")
         default = field.default
@@ -435,6 +440,55 @@ def create_table_from_base_model_cls(model_cls: Type[BaseModel]):
     return table
 
 
+def create_dict_from_field_schemas(
+    fields: Mapping[str, "ValueSchema"],
+    _add_default: bool = True,
+    _add_required: bool = True,
+    _show_header: bool = False,
+    _constants: Union[Mapping[str, Any], None] = None,
+    _doc_to_string: bool = True,
+) -> Mapping[str, List[Any]]:
+
+    table: Dict[str, List[Any]] = {}
+    table["field_name"] = []
+    table["data_type"] = []
+    table["description"] = []
+
+    if _add_required:
+        table["required"] = []
+    if _add_default:
+        table["default"] = []
+
+    for field_name, schema in fields.items():
+
+        table["field_name"].append(field_name)
+        table["data_type"].append(schema.type)
+        if _doc_to_string:
+            table["description"].append(schema.doc.full_doc)
+        else:
+            table["description"].append(schema.doc)
+
+        if _add_required:
+            req = schema.is_required()
+            table["required"].append(req)
+
+        if _add_default:
+            if _constants and field_name in _constants.keys():
+                d = f"{_constants[field_name]} (constant)"
+            else:
+                if schema.default in [
+                    None,
+                    SpecialValue.NO_VALUE,
+                    SpecialValue.NOT_SET,
+                ]:
+                    d = "-- no default --"
+                else:
+                    d = str(schema.default)
+            table["default"].append(d)
+
+    return table
+
+
 def create_table_from_field_schemas(
     fields: Mapping[str, "ValueSchema"],
     _add_default: bool = True,
@@ -616,9 +670,11 @@ def create_table_from_model_object(
 
         p = props.get(field_name, None)
         p_type = None
+        desc = ""
         if p is not None:
             p_type = p.get("type", None)
             # TODO: check 'anyOf' keys
+            desc = p.get("description", "")
 
         if p_type is None:
             p_type = "-- check source --"
@@ -627,7 +683,6 @@ def create_table_from_model_object(
         data = getattr(model, field_name)
         row.append(extract_renderable(data, render_config=render_config))
 
-        desc = p.get("description", "")
         row.append(desc)
         table.add_row(*row)
 
@@ -677,7 +732,14 @@ def extract_renderable(
         rg = Group(*_all)
         return rg
     elif isinstance(item, Enum):
-        return item.value
+        return str(item.value)
+    elif isinstance(item, Exception):
+        msg = str(item)
+        details = KiaraException.get_root_details(item)
+        if details and details != msg:
+            return Group(msg, "", Markdown(details))
+        else:
+            return msg
     else:
         return str(item)
 
@@ -787,15 +849,15 @@ def create_recursive_table_from_model_object(
         data = getattr(model, field_name)
         p = props.get(field_name, None)
         p_type = None
+        desc = None
         if p is not None:
             p_type = p.get("type", None)
             # TODO: check 'anyOf' keys
+            desc = p.get("description", None)
 
         if p_type is not None:
             p_type = f"[i]{p_type}[/i]"
 
-        desc = p.get("description", None)
-
         if not isinstance(data, BaseModel):
             data_renderable = extract_renderable(data, render_config=render_config)
             sub_model = None
