@@ -5,11 +5,12 @@
 # as well as
 # Parity Public License, version 7.0.0 (see https://paritylicense.com/)
 
+import typing
+from typing import Any, Mapping, Sequence, Set, Union
+
 import regex as re
 import structlog
-import typing
 from regex.regex import Pattern
-from typing import Any, Mapping, Sequence, Set, Union
 
 log = structlog.getLogger()
 
@@ -113,7 +114,7 @@ def replace_var_names_in_string(
         if key not in repl_dict.keys():
             if not ignore_missing_keys:
                 raise Exception(
-                    msg=f"Can't insert variable '{key}'. Key not in provided input values, available keys: {', '.join(repl_dict.keys())}",
+                    f"Can't insert variable '{key}'. Key not in provided input values, available keys: {', '.join(repl_dict.keys())}"
                 )
             else:
                 return match[0]
