@@ -13,13 +13,14 @@
     Read more about conftest.py under:
     https://pytest.org/latest/plugins.html
 """
-import pytest
-
 import os
 import tempfile
 import uuid
 from pathlib import Path
 
+import pytest
+
+from kiara import KiaraAPI
 from kiara.context import Kiara
 from kiara.context.config import KiaraConfig
 from kiara.interfaces.python_api.batch import BatchOperation
@@ -92,6 +93,15 @@ def kiara() -> Kiara:
     return kiara
 
 
+@pytest.fixture
+def api() -> KiaraAPI:
+
+    instance_path = create_temp_dir()
+    kc = KiaraConfig.create_in_folder(instance_path)
+    api = KiaraAPI(kc)
+    return api
+
+
 @pytest.fixture(scope="module")
 def presseeded_data_store_minimal() -> Kiara:
 
@@ -137,6 +147,6 @@ def preseeded_data_store() -> Kiara:
 
     batch_op.run(inputs=inputs, save="preseed")
 
-    print(f"kiara data store: {kiara.data_registry.get_archive()}")
+    print(f"kiara data store: {kiara.data_registry.get_archive()}")  # noqa
 
     return kiara
