@@ -1,24 +1,33 @@
 # -*- coding: utf-8 -*-
 
+from kiara import Kiara
+
 #  Copyright (c) 2021, University of Luxembourg / DHARPA project
 #  Copyright (c) 2021, Markus Binsteiner
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
 
-# def test_multiple_kiara_instances():
-#
-#     kiara = Kiara()
-#     kiara_2 = Kiara()
-#
-#     assert kiara.available_operation_ids == kiara_2.available_operation_ids
-#     assert kiara.available_module_types == kiara_2.available_module_types
-#
-#
+def test_multiple_kiara_instances():
+
+    kiara = Kiara()
+    kiara_2 = Kiara()
+
+    assert kiara.id == kiara_2.id
+    assert (
+        kiara.operation_registry.operation_ids
+        == kiara_2.operation_registry.operation_ids
+    )
+    assert (
+        kiara.module_registry.module_types.keys()
+        == kiara_2.module_registry.module_types.keys()
+    )
+
+
 # def test_multiple_kiara_instances_threaded():
 #     def create_kiara_context(ops: typing.List[str]):
 #         kiara = Kiara()
-#         ops.extend(kiara.available_operation_ids)
+#         ops.extend(kiara.operation_registry.operation_ids)
 #
 #     ops_1 = []
 #     ops_2 = []
